@@ -53,7 +53,7 @@ struct caption_widget {
 };
 
 struct fit_prm {
-  GtkWidget *window, *x,*y, *add_plus, *accuracy, *expand, *frame, *combo;
+  GtkWidget *window, *x,*y, *add_plus, *accuracy, *expand, *frame, *shadow, *combo;
   struct font_prm font;
   GtkWidget *caption;
   const char *script;
@@ -66,6 +66,7 @@ loaddatalist(struct fit_prm *prm, const char *datalist)
 {
   FILE *f;
   int i, j, fitnum;
+  char *source, *file, *array;
 
   if (datalist == NULL) {
     return 1;
@@ -86,7 +87,11 @@ loaddatalist(struct fit_prm *prm, const char *datalist)
   prm->fit_num = fitnum;
   for (i = 0; i < fitnum; i++) {
     prm->data[i].file_id = fgets_int(f);
-    prm->data[i].file = fgets_str(f);
+
+    source = fgets_str(f);
+    file = fgets_str(f);
+    array = fgets_str(f);
+
     prm->data[i].id = fgets_int(f);
     prm->data[i].type = fgets_str(f);
     prm->data[i].poly = fgets_int(f);
@@ -94,6 +99,11 @@ loaddatalist(struct fit_prm *prm, const char *datalist)
     for (j = 0; j < PRM_NUM; j++) {
       prm->data[i].prm[j] = fgets_double(f);
     }
+    if (g_strcmp0(source, "array") == 0) {
+      prm->data[i].file = array;
+    } else {
+      prm->data[i].file = file;
+    }
   }
   fclose(f);
 
@@ -135,7 +145,7 @@ savescript(struct fit_prm *prm)
 {
   char *cap, *val;
   FILE *f;
-  int frame, height, textpt, gx, gy, posx, posy, h_inc, i, draw;
+  int frame, shadow, height, textpt, gx, gy, posx, posy, h_inc, i, draw;
   GtkTreeModel *model;
   GtkTreeIter iter;
 
@@ -154,6 +164,7 @@ savescript(struct fit_prm *prm)
     fprintf(f, "new iarray name:textbbox\n");
   }
 
+  shadow = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(prm->shadow));
   textpt = gtk_spin_button_get_value(GTK_SPIN_BUTTON(prm->font.pt)) * 100;
   height = ceil(textpt * 25.4 / 72.0 / 100) * 100;
   gy = posy;
@@ -180,15 +191,17 @@ savescript(struct fit_prm *prm)
 
   if (frame) {
     fprintf(f, "iarray:textlen:map 'int(X/100+0.5)*100'\n");
-    fprintf(f, "new rectangle\n");
-    fprintf(f, "rectangle::x1=%d\n", posx - height / 4);
-    fprintf(f, "rectangle::y1=%d\n", posy);
-    fprintf(f, "rectangle::x2=%d+${iarray:textlen:max}\n", posx + 3 * height / 4);
-    fprintf(f, "rectangle::y2=%d\n", gy + height / 2);
-    fprintf(f, "rectangle::fill_R=0\n");
-    fprintf(f, "rectangle::fill_G=0\n");
-    fprintf(f, "rectangle::fill_B=0\n");
-    fprintf(f, "rectangle::fill=true\n");
+    if (shadow) {
+      fprintf(f, "new rectangle\n");
+      fprintf(f, "rectangle::x1=%d\n", posx - height / 4);
+      fprintf(f, "rectangle::y1=%d\n", posy);
+      fprintf(f, "rectangle::x2=%d+${iarray:textlen:max}\n", posx + 3 * height / 4);
+      fprintf(f, "rectangle::y2=%d\n", gy + height / 2);
+      fprintf(f, "rectangle::fill_R=0\n");
+      fprintf(f, "rectangle::fill_G=0\n");
+      fprintf(f, "rectangle::fill_B=0\n");
+      fprintf(f, "rectangle::fill=true\n");
+    }
     fprintf(f, "new rectangle\n");
     fprintf(f, "rectangle::x1=%d\n", posx - height / 2);
     fprintf(f, "rectangle::y1=%d\n", posy - height / 4);
@@ -212,7 +225,7 @@ savescript(struct fit_prm *prm)
 }
 
 static GtkWidget *
-create_spin_button(const char *title, double min, double max, double inc, double init, GtkWidget **hbox)
+my_create_spin_button(const char *title, double min, double max, double inc, double init, GtkWidget **hbox)
 {
   GtkWidget *w, *label;
 
@@ -223,9 +236,12 @@ create_spin_button(const char *title, double min, double max, double inc, double
   label = gtk_label_new_with_mnemonic(title);
   g_object_set(label, "margin", GINT_TO_POINTER(4), NULL);
 
-  w = gtk_spin_button_new_with_range(min, max, inc);
+  w = create_spin_button(min, max, inc, init, 0);
+#if GTK_CHECK_VERSION(3, 12, 0)
+  gtk_widget_set_margin_end(w, 4);
+#else
   gtk_widget_set_margin_right(w, 4);
-  gtk_spin_button_set_value(GTK_SPIN_BUTTON(w), init);
+#endif
   gtk_label_set_mnemonic_widget(GTK_LABEL(label), w);
   gtk_widget_set_hexpand(w, TRUE);
   gtk_widget_set_halign(w, GTK_ALIGN_FILL);
@@ -237,8 +253,7 @@ create_spin_button(const char *title, double min, double max, double inc, double
   label = gtk_label_new_with_mnemonic(title);
   gtk_box_pack_start(GTK_BOX(*hbox), label, FALSE, FALSE, 4);
 
-  w = gtk_spin_button_new_with_range(min, max, inc);
-  gtk_spin_button_set_value(GTK_SPIN_BUTTON(w), init);
+  w = create_spin_button(min, max, inc, init, 0);
   gtk_label_set_mnemonic_widget(GTK_LABEL(label), w);
   gtk_box_pack_start(GTK_BOX(*hbox), w, TRUE, TRUE, 4);
 #endif
@@ -246,6 +261,16 @@ create_spin_button(const char *title, double min, double max, double inc, double
   return w;
 }
 
+static void
+frame_toggled(GtkToggleButton *togglebutton, gpointer user_data)
+{
+  int state;
+  struct fit_prm *prm;
+
+  prm = (struct fit_prm *) user_data;
+  state = gtk_toggle_button_get_active(togglebutton);
+  gtk_widget_set_sensitive(GTK_WIDGET(prm->shadow), state);
+}
 
 static GtkWidget *
 create_format_frame(struct fit_prm *prm)
@@ -275,8 +300,14 @@ create_format_frame(struct fit_prm *prm)
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(w), FRAME);
   prm->frame = w;
 
+  w = gtk_check_button_new_with_mnemonic("_Shadow");
+  gtk_box_pack_start(GTK_BOX(vbox), w, FALSE, FALSE, 2);
+  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(w), FRAME);
+  prm->shadow = w;
 
-  w = create_spin_button("_Accuracy:", 1, 15, 1, ACCURACY, &hbox);
+  g_signal_connect(prm->frame, "toggled", G_CALLBACK(frame_toggled), prm);
+
+  w = my_create_spin_button("_Accuracy:", 1, 15, 1, ACCURACY, &hbox);
   gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 2);
   prm->accuracy = w;
 
@@ -301,15 +332,11 @@ create_position_frame(struct fit_prm *prm)
 #endif
 
   j = 0;
-  w = gtk_spin_button_new_with_range(POS_MIN, POS_MAX, POS_INC);
-  gtk_spin_button_set_digits(GTK_SPIN_BUTTON(w), 2);
-  gtk_spin_button_set_value(GTK_SPIN_BUTTON(w), prm->posx / 100.0);
+  w = create_spin_button(POS_MIN, POS_MAX, POS_INC, prm->posx / 100.0, 2);
   add_widget_to_table_sub(table, w, "_X:", TRUE, 0, 1, j++);
   prm->x = w;
 
-  w = gtk_spin_button_new_with_range(POS_MIN, POS_MAX, POS_INC);
-  gtk_spin_button_set_digits(GTK_SPIN_BUTTON(w), 2);
-  gtk_spin_button_set_value(GTK_SPIN_BUTTON(w), prm->posy / 100.0);
+  w = create_spin_button(POS_MIN, POS_MAX, POS_INC, prm->posy / 100.0, 2);
   add_widget_to_table_sub(table, w, "_Y:", TRUE, 0, 1, j++);
   prm->y = w;
 
@@ -327,6 +354,9 @@ set_parameter(struct fit_prm *prm)
   GtkTreeIter iter;
 
   i = gtk_combo_box_get_active(GTK_COMBO_BOX(prm->combo));
+  if (i < 0) {
+    return;
+  }
 
   accuracy = gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(prm->accuracy));
   expand = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(prm->expand));
@@ -369,7 +399,7 @@ set_parameter(struct fit_prm *prm)
 	       prm->data[i].prm[j]);
     } else {
       snprintf(buf, sizeof(buf),
-	       "%%pf{%s %%{file:%d:fit_prm:%d}}",
+	       "%%pf{%s %%{data:%d:fit_prm:%d}}",
 	       fmt,
 	       prm->data[i].file_id,
 	       j);
@@ -470,7 +500,9 @@ create_caption_frame(struct fit_prm *prm)
 
   list = gtk_list_store_new(n + 1, G_TYPE_BOOLEAN, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING);
   tview = gtk_tree_view_new_with_model(GTK_TREE_MODEL(list));
+#if ! GTK_CHECK_VERSION(3, 14, 0)
   gtk_tree_view_set_rules_hint(GTK_TREE_VIEW(tview), TRUE);
+#endif
   gtk_tree_view_set_grid_lines(GTK_TREE_VIEW(tview), GTK_TREE_VIEW_GRID_LINES_VERTICAL);
 
   renderer = gtk_cell_renderer_toggle_new();
@@ -655,10 +687,10 @@ main(int argc, char **argv)
   }
 
   mainwin = gtk_dialog_new_with_buttons(NAME, NULL, 0,
-					GTK_STOCK_OK,
-					GTK_RESPONSE_ACCEPT,
-					GTK_STOCK_CANCEL,
+					"_Cancel",
 					GTK_RESPONSE_REJECT,
+					"_OK",
+					GTK_RESPONSE_ACCEPT,
 					NULL);
   gtk_dialog_set_default_response(GTK_DIALOG(mainwin), GTK_RESPONSE_ACCEPT);
   prm.window = mainwin;
