@@ -29,9 +29,15 @@
 #define COLUMN_ID      1
 #define COLUMN_CAPTION 5
 
+enum {
+  PLOT_SOURCE_FILE,
+  PLOT_SOURCE_ARRAY,
+  PLOT_SOURCE_FUNC,
+};
+
 struct file_data {
-  char *file, *math_x, *math_y, *type, *caption, *style;
-  int id, x, y, mark, size, width, r, g, b, r2, g2, b2, show, mix;
+  char *file, *array, *math_x, *math_y, *type, *caption, *style;
+  int id, source, x, y, mark, size, width, r, g, b, r2, g2, b2, show, mix;
 };
 
 struct caption_widget {
@@ -39,7 +45,7 @@ struct caption_widget {
 };
 
 struct file_prm {
-  GtkWidget *window, *x,*y, *width, *mix, *type, *caption, *frame, *files;
+  GtkWidget *window, *x,*y, *width, *mix, *type, *caption, *frame, *shadow, *files;
   struct font_prm font;
   const char *script;
   struct file_data *data;
@@ -96,7 +102,16 @@ loaddatalist(struct file_prm *prm, const char *datalist)
   prm->data = g_malloc(sizeof(*prm->data) * filenum);
   prm->file_num = filenum;
   for (i = 0; i < filenum; i++) {
+    str = fgets_str(f);
+    if (g_strcmp0(str, "array") == 0) {
+      prm->data[i].source = PLOT_SOURCE_ARRAY;
+    } else if (g_strcmp0(str, "function") == 0) {
+      prm->data[i].source = PLOT_SOURCE_FUNC;
+    } else {
+      prm->data[i].source = PLOT_SOURCE_FILE;
+    }
     prm->data[i].file = fgets_str(f);
+    prm->data[i].array = fgets_str(f);
     prm->data[i].id = fgets_int(f);
 
     hidden = fgets_str(f);
@@ -119,16 +134,33 @@ loaddatalist(struct file_prm *prm, const char *datalist)
     prm->data[i].math_x = fgets_str(f);
     prm->data[i].math_y = fgets_str(f);
     prm->data[i].mix = -1;
-    if (prm->data[i].file) {
-      file = g_path_get_basename(prm->data[i].file);
+    str = NULL;
+    file = NULL;
+    if (prm->data[i].source == PLOT_SOURCE_ARRAY) {
+      if (prm->data[i].array) {
+	file = g_strdup(prm->data[i].array);
+	str = escape_char(file, "_^@%\\", "\\");
+      }
+    } else if (prm->data[i].source == PLOT_SOURCE_FUNC) {
+      file = g_strdup_printf("X=%s; Y=%s",
+			     (prm->data[i].math_x[0]) ? prm->data[i].math_x : "X",
+			     (prm->data[i].math_y[0]) ? prm->data[i].math_y : "Y");
       str = escape_char(file, "_^@%\\", "\\");
-      prm->data[i].caption = str;
-      g_free(file);
+      prm->data[i].type = "line";
     } else {
-      prm->data[i].caption = NULL;
+      if (prm->data[i].file) {
+	file = g_path_get_basename(prm->data[i].file);
+	str = escape_char(file, "_^@%\\", "\\");
+      }
+    }
+    prm->data[i].caption = str;
+    if (file) {
+      g_free(file);
     }
     for (j = 0; j < i; j++) {
-      if ((g_strcmp0(prm->data[i].file, prm->data[j].file) == 0) &&
+      if ((prm->data[i].source == prm->data[j].source) &&
+	  (g_strcmp0(prm->data[i].file, prm->data[j].file) == 0) &&
+	  (g_strcmp0(prm->data[i].array, prm->data[j].array) == 0) &&
 	  (prm->data[i].show == prm->data[j].show) &&
 	  (prm->data[i].x == prm->data[j].x) &&
 	  (prm->data[i].y == prm->data[j].y) &&
@@ -199,6 +231,7 @@ makescript(FILE *f, struct file_data *data, int gx, int gy, int width, int heigh
 	(g_strcmp0(data->type, "bar_x") == 0) ||
 	(g_strcmp0(data->type, "bar_y") == 0)) {
       fprintf(f, "rectangle::fill=false\n");
+      fprintf(f, "rectangle::stroke=true\n");
       fprintf(f, "rectangle::stroke_R=%d\n", data->r);
       fprintf(f, "rectangle::stroke_G=%d\n", data->g);
       fprintf(f, "rectangle::stroke_B=%d\n", data->b);
@@ -218,6 +251,7 @@ makescript(FILE *f, struct file_data *data, int gx, int gy, int width, int heigh
 	       (g_strcmp0(data->type, "bar_solid_fill_x") == 0) ||
 	       (g_strcmp0(data->type, "bar_solid_fill_y") == 0)) {;
       fprintf(f, "rectangle::fill=true\n");
+      fprintf(f, "rectangle::stroke=false\n");
       fprintf(f, "rectangle::fill_R=%d\n", data->r);
       fprintf(f, "rectangle::fill_G=%d\n", data->g);
       fprintf(f, "rectangle::fill_B=%d\n", data->b);
@@ -250,7 +284,7 @@ savescript(struct file_prm *prm)
 {
   FILE *f;
   int i, j, height, len, gx, gy, posx, posy, pt, spc, script, r, g, b, style, width;
-  gboolean type, mix, frame, caption;
+  gboolean type, mix, frame, shadow, caption;
   char *str;
   const char *font;
 
@@ -266,6 +300,7 @@ savescript(struct file_prm *prm)
   type = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(prm->type));
   mix = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(prm->mix));
   frame = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(prm->frame));
+  shadow = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(prm->shadow));
   caption = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(prm->caption));
   font = get_selected_font(&prm->font);
 
@@ -325,16 +360,6 @@ savescript(struct file_prm *prm)
   if (frame) {
     fprintf(f, "iarray:textlen:map 'int(X/100+0.5)*100'\n");
     fprintf(f, "new rectangle\n");
-    fprintf(f, "rectangle::x1=%d\n", posx - height / 4);
-    fprintf(f, "rectangle::y1=%d\n", posy);
-    fprintf(f, "rectangle::x2=%d+${iarray:textlen:max}\n", posx + len + 3 * height / 4);
-    fprintf(f, "rectangle::y2=%d\n", gy + height / 2);
-    fprintf(f, "rectangle::fill_R=0\n");
-    fprintf(f, "rectangle::fill_G=0\n");
-    fprintf(f, "rectangle::fill_B=0\n");
-    fprintf(f, "rectangle::fill=true\n");
-    fprintf(f, "rectangle::stroke=false\n");
-    fprintf(f, "new rectangle\n");
     fprintf(f, "rectangle::x1=%d\n", posx - height / 2);
     fprintf(f, "rectangle::y1=%d\n", posy - height / 4);
     fprintf(f, "rectangle::x2=%d+${iarray:textlen:max}\n", posx + len + height / 2);
@@ -348,7 +373,19 @@ savescript(struct file_prm *prm)
     fprintf(f, "rectangle::fill=true\n");
     fprintf(f, "rectangle::stroke=true\n");
     fprintf(f, "movetop rectangle:!\n");
-    fprintf(f, "movetop rectangle:!\n");
+    if (shadow) {
+      fprintf(f, "new rectangle\n");
+      fprintf(f, "rectangle::x1=%d\n", posx - height / 4);
+      fprintf(f, "rectangle::y1=%d\n", posy);
+      fprintf(f, "rectangle::x2=%d+${iarray:textlen:max}\n", posx + len + 3 * height / 4);
+      fprintf(f, "rectangle::y2=%d\n", gy + height / 2);
+      fprintf(f, "rectangle::fill_R=0\n");
+      fprintf(f, "rectangle::fill_G=0\n");
+      fprintf(f, "rectangle::fill_B=0\n");
+      fprintf(f, "rectangle::fill=true\n");
+      fprintf(f, "rectangle::stroke=false\n");
+      fprintf(f, "movetop rectangle:!\n");
+    }
     fprintf(f, "del iarray:textlen\n");
     fprintf(f, "del iarray:textbbox\n");
   }
@@ -359,6 +396,17 @@ savescript(struct file_prm *prm)
   return 0;
 }
 
+static void
+frame_toggled(GtkToggleButton *togglebutton, gpointer user_data)
+{
+  int state;
+  struct file_prm *prm;
+
+  prm = (struct file_prm *) user_data;
+  state = gtk_toggle_button_get_active(togglebutton);
+  gtk_widget_set_sensitive(GTK_WIDGET(prm->shadow), state);
+}
+
 static GtkWidget *
 create_option_frame(struct file_prm *prm)
 {
@@ -393,6 +441,12 @@ create_option_frame(struct file_prm *prm)
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(w), FRAME);
   prm->frame = w;
 
+  w = gtk_check_button_new_with_mnemonic("_Shadow");
+  gtk_box_pack_start(GTK_BOX(vbox), w, FALSE, FALSE, 2);
+  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(w), FRAME);
+  prm->shadow = w;
+
+  g_signal_connect(prm->frame, "toggled", G_CALLBACK(frame_toggled), prm);
 
   gtk_container_add(GTK_CONTAINER(frame), vbox);
 
@@ -414,21 +468,15 @@ create_geometry_frame(struct file_prm *prm)
 #endif
 
   j = 0;
-  w = gtk_spin_button_new_with_range(POS_MIN, POS_MAX, POS_INC);
-  gtk_spin_button_set_digits(GTK_SPIN_BUTTON(w), 2);
-  gtk_spin_button_set_value(GTK_SPIN_BUTTON(w), prm->posx / 100.0);
+  w = create_spin_button(POS_MIN, POS_MAX, POS_INC, prm->posx / 100.0, 2);
   add_widget_to_table_sub(table, w, "_X:", TRUE, 0, 1, j++);
   prm->x = w;
 
-  w = gtk_spin_button_new_with_range(POS_MIN, POS_MAX, POS_INC);
-  gtk_spin_button_set_digits(GTK_SPIN_BUTTON(w), 2);
-  gtk_spin_button_set_value(GTK_SPIN_BUTTON(w), prm->posy / 100.0);
+  w = create_spin_button(POS_MIN, POS_MAX, POS_INC, prm->posy / 100.0, 2);
   add_widget_to_table_sub(table, w, "_Y:", TRUE, 0, 1, j++);
   prm->y = w;
 
-  w = gtk_spin_button_new_with_range(1, 100, 10);
-  gtk_spin_button_set_digits(GTK_SPIN_BUTTON(w), 2);
-  gtk_spin_button_set_value(GTK_SPIN_BUTTON(w), prm->w / 100.0);
+  w = create_spin_button(1, 100, 10, prm->w / 100.0, 2);
   add_widget_to_table_sub(table, w, "_Width:", TRUE, 0, 1, j++);
   prm->width = w;
 
@@ -441,7 +489,7 @@ static void
 set_parameter(struct file_prm *prm)
 {
   int i, mix;
-  char *basename;
+  char *caption;
   GtkTreeIter iter;
   GtkListStore *list;
 
@@ -457,16 +505,22 @@ set_parameter(struct file_prm *prm)
     }
     gtk_list_store_append(list, &iter);
 
-    basename = g_path_get_basename(prm->data[i].file);
+    if (prm->data[i].source == PLOT_SOURCE_ARRAY) {
+      caption = g_strdup(prm->data[i].array);
+    } else if (prm->data[i].source == PLOT_SOURCE_FUNC) {
+      caption = g_strdup("function");
+    } else {
+      caption = g_path_get_basename(prm->data[i].file);
+    }
     gtk_list_store_set(list, &iter,
 		       0, prm->data[i].show,
 		       1, prm->data[i].id,
-		       2, basename,
+		       2, caption,
 		       3, prm->data[i].x,
 		       4, prm->data[i].y,
 		       5, prm->data[i].caption,
 		       -1);
-    g_free(basename);
+    g_free(caption);
   }
 }
 
@@ -540,13 +594,15 @@ create_file_frame(struct file_prm *prm)
   GtkTreeViewColumn *col;
   GtkWidget *tview, *hbox, *swin, *frame;
   int i, n;
-  char *title[] = {"#", "File", "x", "y", "Caption"};
+  char *title[] = {"#", "Source", "x", "y", "Caption"};
 
   n = sizeof(title) / sizeof(*title);
 
   list = gtk_list_store_new(n + 1, G_TYPE_BOOLEAN, G_TYPE_INT, G_TYPE_STRING, G_TYPE_INT, G_TYPE_INT, G_TYPE_STRING);
   tview = gtk_tree_view_new_with_model(GTK_TREE_MODEL(list));
+#if ! GTK_CHECK_VERSION(3, 14, 0)
   gtk_tree_view_set_rules_hint(GTK_TREE_VIEW(tview), TRUE);
+#endif
   gtk_tree_view_set_grid_lines(GTK_TREE_VIEW(tview), GTK_TREE_VIEW_GRID_LINES_VERTICAL);
 
   renderer = gtk_cell_renderer_toggle_new();
@@ -680,10 +736,10 @@ main(int argc, char **argv)
   }
 
   mainwin = gtk_dialog_new_with_buttons(NAME, NULL, 0,
-					GTK_STOCK_OK,   
-					GTK_RESPONSE_ACCEPT,
-					GTK_STOCK_CANCEL,   
+					"_Cancel",
 					GTK_RESPONSE_REJECT,
+					"_Ok",
+					GTK_RESPONSE_ACCEPT,
 					NULL);
   gtk_dialog_set_default_response(GTK_DIALOG(mainwin), GTK_RESPONSE_ACCEPT);
   prm.window = mainwin;
