@@ -1,6 +1,6 @@
 #! /bin/sh
 
-if [ $# -ne 7 ]
+if [ $# -ne 8 ]
 then
     echo "error: wrong number of arguments ($0)."
     exit
@@ -10,6 +10,8 @@ BINDIR=$1
 shift
 DOCDIR=$1
 shift
+LIBEXECDIR=$1
+shift
 LIBDIR=$1
 shift
 DATADIR=$1
@@ -26,6 +28,7 @@ export LC_ALL
 
 cat $1 | sed -e "s!BINDIRDEF!$BINDIR!g" \
              -e "s!DOCDIRDEF!$DOCDIR!g" \
+             -e "s!LIBEXECDIRDEF!$LIBEXECDIR!g" \
              -e "s!LIBDIRDEF!$LIBDIR!g" \
              -e "s!DATADIRDEF!$DATADIR!g" \
              -e "s!PIXMAPDIRDEF!$PIXMAPDIR!g" \
