@@ -44,11 +44,10 @@
 
 #define MARK_TYPE_NUM 90
 
-int printfconsole(char *fmt,...);
+int printfconsole(const char *fmt,...);
 int putconsole(const char *s);
-int printfconsole(char *fmt,...);
+int printfconsole(const char *fmt,...);
 void displaydialog(const char *str);
 void displaystatus(const char *str);
-void pausewindowconsole(char *title,char *str);
 
 #endif	/* COMMON_HEADER */
