@@ -46,8 +46,8 @@
 
 struct GRAC {
   int open,init;
-  char *objname;
-  char *outputname;
+  const char *objname;
+  const char *outputname;
   struct objlist *obj;
   N_VALUE *inst;
   int output,strwidth,charascent,chardescent;
@@ -166,7 +166,7 @@ _GRAopencallback(directfunc direct,struct narray **list,void *local)
 }
 
 int 
-_GRAopen(char *objname,char *outputname,
+_GRAopen(const char *objname, const char *outputname,
 	 struct objlist *obj,N_VALUE *inst, int output,
 	 int strwidth,int charascent,int chardescent,
 	 struct narray **list,void *local)
@@ -178,8 +178,8 @@ _GRAopen(char *objname,char *outputname,
   GRAClist[i]=GRAClist[GRAClimit];
   GRAClist[i].open=TRUE;
   GRAClist[i].init=FALSE;
-  GRAClist[i].objname=objname;
-  GRAClist[i].outputname=outputname;
+  GRAClist[i].objname=(char *) objname;
+  GRAClist[i].outputname=(char*) outputname;
   GRAClist[i].obj=obj;
   GRAClist[i].inst=inst;
   GRAClist[i].output=output;
@@ -193,7 +193,7 @@ _GRAopen(char *objname,char *outputname,
 }
 
 int 
-GRAopen(char *objname,char *outputname,
+GRAopen(const char *objname,const char *outputname,
 	struct objlist *obj,N_VALUE *inst, int output,
 	int strwidth,int charascent,int chardescent,
 	struct narray **list,void *local)
@@ -345,7 +345,7 @@ GRAinslist2(int GC,char *draw,int n)
 
 void 
 GRAaddlist(int GC,struct objlist *obj,N_VALUE *inst,
-                char *objname,char *field)
+                const char *objname, const char *field)
 {
   int oid;
   char *draw;
@@ -358,7 +358,7 @@ GRAaddlist(int GC,struct objlist *obj,N_VALUE *inst,
 
 void 
 GRAinslist(int GC,struct objlist *obj,N_VALUE *inst,
-                char *objname,char *field,int n)
+                const char *objname, const char *field,int n)
 {
   int oid;
   char *draw;
@@ -403,7 +403,7 @@ GRAgetlist(int GC,int *oid,char **field,int n)
 
 void 
 _GRAredraw(int GC,int snum,char **sdata,int setredrawf,int redraw_num,
-                int addn,struct objlist *obj,N_VALUE *inst,char *field)
+                int addn,struct objlist *obj,N_VALUE *inst,const char *field)
 {
   int i;
   char *dargv[2];
@@ -626,8 +626,8 @@ GRAdraw(int GC,char code,int *cpar,char *cstr)
     break;
   }
   if (GRAClist[GC].direct==NULL) {
-    argv[0]=GRAClist[GC].objname;
-    argv[1]=GRAClist[GC].outputname;
+    argv[0]=(char *) GRAClist[GC].objname;
+    argv[1]=(char *) GRAClist[GC].outputname;
     argv[2]=GRAClist[GC].local;
     argv[3]=&code;
     argv[4]=(char *)cpar;
@@ -654,7 +654,7 @@ GRAstrwidth(const gchar *s, char *font, int style, int size)
     return nround(25.4 / 72000.0 * size * 600);
   }
 
-  argv[0] = GRAClist[i].objname;
+  argv[0] = (char *) GRAClist[i].objname;
   argv[1] = "_strwidth";
   argv[2] = GRAClist[i].local;
   argv[3] = (char *) s;
@@ -683,7 +683,7 @@ GRAcharascent(char *font, int style, int size)
   if (i == -1)
     return nround(25.4 / 72000.0 * size * 563);
 
-  argv[0] = GRAClist[i].objname;
+  argv[0] = (char *) GRAClist[i].objname;
   argv[1] = "_charascent";
   argv[2] = GRAClist[i].local;
   argv[3] = (char *)&size;
@@ -711,7 +711,7 @@ GRAchardescent(char *font,int style,int size)
   if (i == -1)
     return nround(25.4 / 72000.0 * size * 250);
 
-  argv[0] = GRAClist[i].objname;
+  argv[0] = (char *) GRAClist[i].objname;
   argv[1] = "_chardescent";
   argv[2] = GRAClist[i].local;
   argv[3] = (char *)&size;
@@ -2054,7 +2054,7 @@ GRAdrawtext(int GC, char *s, char *font, int style,
   int len, scmovex, scmovey, scriptf, scx_max, scy_max, scdist_max;
   char *endptr;
   char *font2;
-  int size2, space2, style2;
+  int size2, space2, style2, vspace;
   char *font3;
   int size3, space3, style3;
   int i, k, x, y, val, x0, y0, x1, y1;
@@ -2075,6 +2075,7 @@ GRAdrawtext(int GC, char *s, char *font, int style,
   si = sin(dir * MPI / 18000);
   x0 = GRAClist[GC].cpx;
   y0 = GRAClist[GC].cpy;
+  vspace = 0;
  
   str = g_string_sized_new(128);
   if (str == NULL) {
@@ -2176,7 +2177,7 @@ GRAdrawtext(int GC, char *s, char *font, int style,
         space2 = space3;
       }
       x0 += scx_max;
-      y0 += scy_max;
+      y0 += scy_max + vspace;
       scdist_max = 0;
       scx_max = 0;
       scy_max = 0;
@@ -2259,7 +2260,7 @@ GRAdrawtext(int GC, char *s, char *font, int style,
       ptr++;
       break;
     case '%':
-      if ((ptr[1]!='\0') && (strchr("FJSPXYCA", toupper(ptr[1]))!=NULL) && (ptr[2]=='{')) {
+      if ((ptr[1]!='\0') && ( strchr("FJSPNXYCA", toupper(ptr[1]))!=NULL) && (ptr[2]=='{')) {
         for (i = 3; ptr[i] != '\0' && ptr[i] != '}'; i++);
         if (ptr[i] == '}') {
 	  tok=g_malloc(i - 2);
@@ -2287,6 +2288,11 @@ GRAdrawtext(int GC, char *s, char *font, int style,
               if (endptr[0]=='\0') space2=val * 100;
               g_free(tok);
               break;
+            case 'N':
+              val=strtol(tok, &endptr, 10);
+              if (endptr[0]=='\0') vspace=val * 100;
+              g_free(tok);
+              break;
             case 'X':
               val=strtol(tok, &endptr, 10);
               if (endptr[0]=='\0') GRAmoverel(GC, (int) (val * 100 * 25.4 / 72.0), 0);
@@ -2335,7 +2341,7 @@ GRAdrawtext(int GC, char *s, char *font, int style,
   }
 
 errexit:
-  if  (str) {
+  if (str) {
     g_string_free(str, TRUE);
   }
   g_free(c);
@@ -2384,7 +2390,7 @@ GRAtextextent(char *s, char *font, int style,
   int w, h, d, len, scmovey, scriptf, scy_max;
   char *endptr;
   char *font2;
-  int size2, space2, style2;
+  int size2, space2, style2, vspace;
   char *font3;
   int size3, space3, style3;
   int i, j, k, y, val, x0, y0;
@@ -2419,6 +2425,7 @@ GRAtextextent(char *s, char *font, int style,
   scriptf = 0;
   scmovey = 0;
   scy_max = 0;
+  vspace = 0;
 
   len = strlen(c);
 
@@ -2518,7 +2525,7 @@ GRAtextextent(char *s, char *font, int style,
         size2 = size3;
         space2 = space3;
       }
-      y0 += scy_max;
+      y0 += scy_max + vspace;
       scmovey = 0;
       scy_max = 0;
       if (! raw && alignlen) {
@@ -2586,7 +2593,7 @@ GRAtextextent(char *s, char *font, int style,
       j++;
       break;
     case '%':
-      if (c[j + 1] != '\0' && strchr("FJSPXYCA", toupper(c[j + 1])) && c[j + 2] == '{') {
+      if (c[j + 1] != '\0' && strchr("FJSPNXYCA", toupper(c[j + 1])) && c[j + 2] == '{') {
         for (i = j + 3; c[i] != '\0' && c[i] != '}'; i++);
         if (c[i] == '}') {
 	  tok = g_malloc(i - j - 2);
@@ -2620,6 +2627,13 @@ GRAtextextent(char *s, char *font, int style,
 	      }
               g_free(tok);
               break;
+            case 'N':
+              val = strtol(tok, &endptr, 10);
+              if (endptr[0] == '\0') {
+		vspace = val * 100;
+	      }
+              g_free(tok);
+              break;
             case 'X':
               val = strtol(tok, &endptr, 10);
               if (endptr[0] == '\0') {
