@@ -13,6 +13,10 @@
 #define GTK_WIDGET_VISIBLE(w) gtk_widget_get_visible(w)
 #endif
 
+#define USE_HEADER_BAR 0
+#define USE_APP_MENU GTK_CHECK_VERSION(3, 12, 0)
+#define USE_GTK_BUILDER 0
+
 #if GTK_CHECK_VERSION(2, 18, 0)
 #define GTK_WIDGET_SET_CAN_FOCUS(w) gtk_widget_set_can_focus(w, TRUE)
 #else
@@ -74,5 +78,7 @@
 #define GDK_KEY_x GDK_x
 #endif	/* GDK_KEY_BackSpace */
 
+#define LINE_NUMBER_WIDGET_NAME "line_number"
+
 #endif
 
