@@ -12,6 +12,56 @@
 #include "x11dialg.h"
 
 
+static gboolean
+tree_view_set_tooltip_query_cb(GtkWidget  *widget,
+			       gint        x,
+			       gint        y,
+			       gboolean    keyboard_tip,
+			       GtkTooltip *tooltip,
+			       gpointer    data)
+{
+  char *str;
+  GtkTreeIter iter;
+  GtkTreePath *path;
+  GtkTreeModel *model;
+  GtkTreeView *tree_view = GTK_TREE_VIEW(widget);
+  int column;
+
+  if (!gtk_tree_view_get_tooltip_context(GTK_TREE_VIEW(widget),
+					 &x, &y,
+					 keyboard_tip,
+					 &model, &path, &iter)) {
+    return FALSE;
+  }
+
+  column = GPOINTER_TO_INT(data);
+  if (column < 0) {
+    return FALSE;
+  }
+
+  str = NULL;
+  gtk_tree_model_get(model, &iter, column, &str, -1);
+  if (str == NULL) {
+    return FALSE;
+  }
+
+  gtk_tooltip_set_text(tooltip, str);
+  gtk_tree_view_set_tooltip_row(tree_view, tooltip, path);
+
+  g_free(str);
+  gtk_tree_path_free(path);
+
+  return TRUE;
+}
+
+void
+tree_view_set_tooltip_column(GtkTreeView *tree_view, gint column)
+{
+  g_signal_connect(tree_view, "query-tooltip",
+		   G_CALLBACK(tree_view_set_tooltip_query_cb), GINT_TO_POINTER(column));
+  gtk_widget_set_has_tooltip(GTK_WIDGET(tree_view), TRUE);
+}
+
 static gboolean
 combo_box_separator_func(GtkTreeModel *model, GtkTreeIter *iter, gpointer data)
 {
@@ -222,7 +272,7 @@ add_line_style_item_to_cbox(GtkTreeStore *list, GtkTreeIter *parent, int column_
 
   add_text_combo_item_to_cbox(list, &iter, parent, -1, -1, _("Line style"), TOGGLE_NONE, FALSE);
   for (i = 0; FwLineStyle[i].name; i++) {
-    active = ! strcmp(str, FwLineStyle[i].list);
+    active = ! g_strcmp0(str, FwLineStyle[i].list);
     add_text_combo_item_to_cbox(list, NULL, &iter, column_id, i, _(FwLineStyle[i].name), TOGGLE_RADIO, active);
   }
   g_free(str);
@@ -423,7 +473,9 @@ create_tree_view(int n, n_list_store *list, int tree)
 
   tview = gtk_tree_view_new_with_model(lstore);
 
+#if ! GTK_CHECK_VERSION(3, 14, 0)
   gtk_tree_view_set_rules_hint(GTK_TREE_VIEW(tview), TRUE);
+#endif
   gtk_tree_view_set_rubber_banding(GTK_TREE_VIEW(tview), TRUE);
   gtk_tree_view_set_grid_lines(GTK_TREE_VIEW(tview), GTK_TREE_VIEW_GRID_LINES_VERTICAL);
 
