@@ -49,6 +49,10 @@ typedef struct _Nruler {
   double lower, upper, position;
   double save_l, save_u;
   GtkWidget *widget, *parent;
+#if GTK_CHECK_VERSION(3, 0, 0)
+  GtkStyleContext *saved_style;
+  GdkRGBA saved_fg;
+#endif
 } Nruler;
 
 struct _NrulerMetric
@@ -76,7 +80,7 @@ static gboolean nruler_destroy(GtkWidget *widget, gpointer user_data);
 #if GTK_CHECK_VERSION(3, 0, 0)
 static void nruler_draw_pos(Nruler *ruler, GtkWidget *widget, cairo_t *cr);
 static gboolean nruler_expose(GtkWidget *widget, cairo_t *cr, gpointer user_data);
-static void nruler_get_color(Nruler *ruler, GdkRGBA *fg, GdkRGBA *bg);
+static GtkStyleContext *nruler_get_color(Nruler *ruler, GdkRGBA *fg);
 #else	/* GTK_CHECK_VERSION(3, 0, 0) */
 static void nruler_draw_pos(Nruler *ruler, GtkWidget *widget);
 static gboolean nruler_expose(GtkWidget *widget, GdkEventExpose *event, gpointer user_data);
@@ -108,6 +112,9 @@ nruler_new(GtkOrientation orientation)
   ruler->orientation = orientation;
   ruler->widget = w;
   ruler->parent = frame;
+#if GTK_CHECK_VERSION(3, 0, 0)
+  ruler->saved_style = NULL;
+#endif
 
   g_object_set_data(G_OBJECT(frame), RULER_DATA_KEY, ruler);
 
@@ -318,7 +325,8 @@ nruler_draw_ticks(Nruler *ruler, GtkWidget *widget)
   PangoFontDescription *fs;
   GtkAllocation allocation;
 #if GTK_CHECK_VERSION(3, 0, 0)
-  GdkRGBA bg, fg;
+  GdkRGBA fg;
+  GtkStyleContext *context;
 #else
   GdkColor bg, fg;
 #endif
@@ -343,16 +351,18 @@ nruler_draw_ticks(Nruler *ruler, GtkWidget *widget)
 
   digit_height = PANGO_PIXELS(ink_rect.height) + 2;
 
-  nruler_get_color(ruler, &fg, &bg);
 #if GTK_CHECK_VERSION(3, 0, 0)
+  context = nruler_get_color(ruler, &fg);
   cr = cairo_create(ruler->backing_store);
-  gdk_cairo_set_source_rgba(cr, &bg);
+  gtk_render_background(context, cr,
+			0, 0, allocation.width, allocation.height);
 #else	/* GTK_CHECK_VERSION(3, 0, 0) */
+  nruler_get_color(ruler, &fg, &bg);
   cr = gdk_cairo_create(ruler->backing_store);
   gdk_cairo_set_source_color(cr, &bg);
-#endif	/* GTK_CHECK_VERSION(3, 0, 0) */
   cairo_rectangle(cr, 0, 0, allocation.width, allocation.height);
   cairo_fill(cr);
+#endif	/* GTK_CHECK_VERSION(3, 0, 0) */
 
 #if GTK_CHECK_VERSION(3, 0, 0)
   gdk_cairo_set_source_rgba(cr, &fg);
@@ -485,36 +495,20 @@ nruler_draw_ticks(Nruler *ruler, GtkWidget *widget)
 }
 
 #if GTK_CHECK_VERSION(3, 0, 0)
-static void
-nruler_get_color(Nruler *ruler, GdkRGBA *fg, GdkRGBA *bg)
+static GtkStyleContext *
+nruler_get_color(Nruler *ruler, GdkRGBA *fg)
 {
-  GdkRGBA color;
-  GtkStyleContext *style;
-
-  style = gtk_widget_get_style_context(TopLevel);
-  gtk_style_context_get_background_color(style, GTK_STATE_FLAG_NORMAL, &color);
-  color.alpha = 1.0;
-
-  if (bg) {
-    *bg = color;
+  if (ruler->saved_style == NULL) {
+    ruler->saved_style = gtk_widget_get_style_context(TopLevel);
+    gtk_style_context_get_color(ruler->saved_style, GTK_STATE_FLAG_NORMAL, &ruler->saved_fg);
   }
 
-  if (fg) {
-#if 0
-    if (color.red + color.green + color.blue > 1.5) {
-      fg->red = 0.0;
-      fg->green = 0.0;
-      fg->blue = 0.0;
-    } else {
-      fg->red = 1.0;
-      fg->green = 1.0;
-      fg->blue = 1.0;
-    }
-    fg->alpha = 1.0;
-#else
-    gtk_style_context_get_color(style, GTK_STATE_FLAG_NORMAL, fg);
-#endif
+  if (fg == NULL) {
+    return ruler->saved_style;
   }
+
+  *fg = ruler->saved_fg;
+  return ruler->saved_style;
 }
 #else
 static void
@@ -606,10 +600,11 @@ nruler_draw_pos(Nruler *ruler, GtkWidget *widget)
     y = nround((ruler->position - ruler->lower) * increment) - bs_height / 2 - ruler->ofst;
   }
 
-  nruler_get_color(ruler, &fg, NULL);
 #if GTK_CHECK_VERSION(3, 0, 0)
+  nruler_get_color(ruler, &fg);
   gdk_cairo_set_source_rgba(cr, &fg);
 #else	/* GTK_CHECK_VERSION(3, 0, 0) */
+  nruler_get_color(ruler, &fg, NULL);
   gdk_cairo_set_source_color(cr, &fg);
 #endif	/* GTK_CHECK_VERSION(3, 0, 0) */
 
