@@ -9,11 +9,13 @@
 #include <math.h>
 #include <libgen.h>
 
+#include "dir_defs.h"
+
 #include "object.h"
 #include "nstring.h"
 #include "mathfn.h"
 
-#include "main.h"
+#include "init.h"
 #include "ox11menu.h"
 #include "x11menu.h"
 #include "x11view.h"
@@ -32,6 +34,28 @@ static void modify_numeric(struct obj_list_data *d, char *field, int val);
 static void modify_string(struct obj_list_data *d, char *field, char *str);
 static void toggle_boolean(struct obj_list_data *d, char *field, int sel);
 
+void
+set_cell_attribute_source(struct SubWin *d, const char *attr, int target_column, int source_column)
+{
+  GList *list;
+  GtkTreeViewColumn *col;
+  GtkCellRenderer *renderer;
+
+  col = gtk_tree_view_get_column(GTK_TREE_VIEW(d->data.data->text), target_column);
+  list = gtk_cell_layout_get_cells(GTK_CELL_LAYOUT(col));
+  if (list == NULL) {
+    return;
+  }
+
+  if (list->data == NULL) {
+    return;
+  }
+
+  renderer = list->data;
+  gtk_tree_view_column_add_attribute(col, renderer, attr, source_column);
+  g_list_free(list);
+}
+
 static void
 file_select(GtkEntry *w, GtkEntryIconPosition icon_pos, GdkEvent *event, gpointer user_data)
 {
@@ -42,7 +66,6 @@ file_select(GtkEntry *w, GtkEntryIconPosition icon_pos, GdkEvent *event, gpointe
 
   d = user_data;
 
-
   sel = list_store_get_selected_int(GTK_WIDGET(d->text), COL_ID);
   num = chkobjlastinst(d->obj);
   if (sel < 0 || sel > num) {
@@ -122,7 +145,7 @@ start_editing_enum(GtkCellEditable *editable, struct obj_list_data *d, n_list_st
   g_signal_connect(cbox, "changed", G_CALLBACK(select_enum), d);
 }
 
-#if GTK_CHECK_VERSION(3, 8, 0)
+#if GTK_CHECK_VERSION(3, 8, 0) && ! GTK_CHECK_VERSION(3, 18, 0)
 static void
 spin_button_size_allocated(GtkWidget *widget, GdkRectangle *allocation, gpointer user_data)
 {
@@ -188,7 +211,7 @@ start_editing(GtkCellRenderer *renderer, GtkCellEditable *editable, gchar *path,
 	char *valstr;
 
 	if (strcmp(list->name, "file") == 0) {
-	  gtk_entry_set_icon_from_stock(GTK_ENTRY(editable), GTK_ENTRY_ICON_SECONDARY, GTK_STOCK_OPEN);
+	  gtk_entry_set_icon_from_icon_name(GTK_ENTRY(editable), GTK_ENTRY_ICON_SECONDARY, "document-open");
 	  g_signal_connect(editable, "icon-release", G_CALLBACK(file_select), d);
 	}
 	sgetobjfield(d->obj, sel, list->name, NULL, &valstr, FALSE, FALSE, FALSE);
@@ -206,7 +229,7 @@ start_editing(GtkCellRenderer *renderer, GtkCellEditable *editable, gchar *path,
   case G_TYPE_DOUBLE:
   case G_TYPE_INT:
     if (GTK_IS_SPIN_BUTTON(editable)) {
-#if GTK_CHECK_VERSION(3, 8, 0)
+#if GTK_CHECK_VERSION(3, 8, 0) && ! GTK_CHECK_VERSION(3, 18, 0)
       g_signal_connect(editable, "size-allocate", G_CALLBACK(spin_button_size_allocated), NULL);
 #endif
       gtk_entry_set_alignment(GTK_ENTRY(editable), 1.0);
@@ -690,6 +713,8 @@ sub_window_hide(struct SubWin *d)
   if (d->Win) {
     sub_window_save_geometry(d);
     gtk_widget_hide(d->Win);
+    d->visible = FALSE;
+    set_toggle_action_widget_state(d->action_widget_id, FALSE);
   }
 }
 
@@ -698,6 +723,8 @@ sub_window_show(struct SubWin *d)
 {
   if (d->Win) {
     gtk_window_present(GTK_WINDOW(d->Win));
+    d->visible = TRUE;
+    set_toggle_action_widget_state(d->action_widget_id, TRUE);
   }
 }
 
@@ -716,7 +743,7 @@ sub_window_set_visibility(struct SubWin *d, int state)
     return;
   }
 
-  if (state) {
+  if (state && ! Menulocal.single_window_mode) {
     if (! gtk_widget_get_realized(d->Win)) {
       sub_window_show_all(d);
       sub_window_set_geometry(d, TRUE);
@@ -745,7 +772,7 @@ cb_del(GtkWidget *w, GdkEvent *event, gpointer user_data)
   struct SubWin *d;
 
   d = (struct SubWin *) user_data;
-  window_action_set_active(d->type, FALSE);
+  set_subwindow_state(d->type, SUBWIN_STATE_HIDE);
 
   return TRUE;
 }
@@ -1107,6 +1134,7 @@ set_hidden_state(struct obj_list_data *d, int hide)
   }
 }
 
+#if ! GTK_CHECK_VERSION(3, 22, 0)
 static void
 popup_menu_position(GtkMenu *menu, gint *x, gint *y, gboolean *push_in, gpointer user_data)
 {
@@ -1118,19 +1146,21 @@ popup_menu_position(GtkMenu *menu, gint *x, gint *y, gboolean *push_in, gpointer
   gdk_win = gtk_widget_get_window(w);
   gdk_window_get_origin(gdk_win, x, y);
 }
+#endif
 
 static void
 do_popup(GdkEventButton *event, struct obj_list_data *d)
 {
+#if GTK_CHECK_VERSION(3, 22, 0)
+  gtk_menu_popup_at_pointer(GTK_MENU(d->popup), ((GdkEvent *)event));
+#else
   int button, event_time;
   GtkMenuPositionFunc func;
 
   if (event) {
-    button = event->button;
     event_time = event->time;
     func = NULL;
   } else {
-    button = 0;
     event_time = gtk_get_current_event_time();
     func = popup_menu_position;
   }
@@ -1142,7 +1172,12 @@ do_popup(GdkEventButton *event, struct obj_list_data *d)
     d->select = list_store_get_selected_int(GTK_WIDGET(d->text), COL_ID);
   }
 
+  /* If the menu popup was initiated by something other than a mouse
+     button press, such as a mouse button release or a keypress,
+     button should be 0. */
+  button = 0;
   gtk_menu_popup(GTK_MENU(d->popup), NULL, NULL, func, d->text, button, event_time);
+#endif
 }
 
 static gboolean
@@ -1166,9 +1201,6 @@ ev_button_down(GtkWidget *w, GdkEventButton *event,  gpointer user_data)
 
   d = user_data;
 
-  if (d->ev_button && d->ev_button(w, event, user_data))
-    return TRUE;
-
   switch (event->button) {
   case 1:
     if (event->type == GDK_2BUTTON_PRESS) {
@@ -1297,14 +1329,13 @@ ev_sub_win_key_down(GtkWidget *w, GdkEvent *event, gpointer user_data)
 
   e = (GdkEventKey *)event;
 
-
   switch (e->keyval) {
   case GDK_KEY_w:
     if (e->state & GDK_CONTROL_MASK) {
-      window_action_set_active(d->type, FALSE);
+      set_subwindow_state(d->type, SUBWIN_STATE_HIDE);
       return TRUE;
     }
-    return FALSE;
+    break;
   }
   return FALSE;
 }
@@ -1335,7 +1366,7 @@ swin_realized(GtkWidget *widget, gpointer user_data)
 }
 
 static GtkWidget *
-sub_window_create(struct SubWin *d, const char *title, GtkWidget *swin, const char **xpm, const char **xpm2)
+sub_window_create(struct SubWin *d, const char *title, GtkWidget *swin, const char *iconfile, const char *iconfile2)
 {
   GtkWidget *dlg;
   GdkPixbuf *icon;
@@ -1347,26 +1378,47 @@ sub_window_create(struct SubWin *d, const char *title, GtkWidget *swin, const ch
 
   d->Win = dlg;
 
-  if (xpm) {
-    icon = gdk_pixbuf_new_from_xpm_data(xpm);
-    if (xpm2) {
+  if (iconfile) {
+#ifdef WINDOWS
+    char *str;
+    str = g_strdup_printf("%s%s", PIXMAPDIR, iconfile);
+    icon = gdk_pixbuf_new_from_file(str, NULL);
+    g_free(str);
+#else
+    icon = gdk_pixbuf_new_from_file(iconfile, NULL);
+#endif
+
+    if (iconfile2) {
       GList *tmp, *list = NULL;
 
-      list = g_list_append(list, icon);
+      if (icon) {
+	list = g_list_append(list, icon);
+      }
 
-      icon = gdk_pixbuf_new_from_xpm_data(xpm2);
-      list = g_list_append(list, icon);
+#ifdef WINDOWS
+      str = g_strdup_printf("%s%s", PIXMAPDIR, iconfile2);
+      icon = gdk_pixbuf_new_from_file(str, NULL);
+      g_free(str);
+#else
+      icon = gdk_pixbuf_new_from_file(iconfile2, NULL);
+#endif
+      if (icon) {
+	list = g_list_append(list, icon);
+      }
 
-      gtk_window_set_icon_list(GTK_WINDOW(dlg), list);
-
-      tmp = list;
-      while (tmp) {
-	g_object_unref(tmp->data);
-	tmp = tmp->next;
+      if (list) {
+	gtk_window_set_icon_list(GTK_WINDOW(dlg), list);
+	tmp = list;
+	while (tmp) {
+	  g_object_unref(tmp->data);
+	  tmp = tmp->next;
+	}
+	g_list_free(list);
       }
-      g_list_free(list);
     } else {
-      gtk_window_set_icon(GTK_WINDOW(dlg), icon);
+      if (icon) {
+	gtk_window_set_icon(GTK_WINDOW(dlg), icon);
+      }
     }
   }
   if (title) {
@@ -1400,7 +1452,7 @@ sub_window_create(struct SubWin *d, const char *title, GtkWidget *swin, const ch
 }
 
 GtkWidget *
-text_sub_window_create(struct SubWin *d, const char *title, const char **xpm, const char **xpm2)
+text_sub_window_create(struct SubWin *d, const char *title, const char *icon, const char *icon2)
 {
   GtkWidget *view, *swin;
   GtkTextBuffer *buf;
@@ -1416,11 +1468,11 @@ text_sub_window_create(struct SubWin *d, const char *title, const char **xpm, co
   gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(swin), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
   gtk_container_add(GTK_CONTAINER(swin), view);
 
-  return sub_window_create(d, title, swin, xpm, xpm2);
+  return sub_window_create(d, title, swin, icon, icon2);
 }
 
 GtkWidget *
-label_sub_window_create(struct SubWin *d, const char *title, const char **xpm, const char **xpm2)
+label_sub_window_create(struct SubWin *d, const char *title, const char *icon, const char *icon2)
 {
   GtkWidget *label, *swin;
 
@@ -1445,7 +1497,7 @@ label_sub_window_create(struct SubWin *d, const char *title, const char **xpm, c
   gtk_scrolled_window_add_with_viewport(GTK_SCROLLED_WINDOW(swin), label);
 #endif
 
-  return sub_window_create(d, title, swin, xpm, xpm2);
+  return sub_window_create(d, title, swin, icon, icon2);
 }
 
 static gboolean
@@ -1506,7 +1558,7 @@ list_widget_create(struct SubWin *d, int lisu_num, n_list_store *list, int can_f
 }
 
 GtkWidget *
-list_sub_window_create(struct SubWin *d, const char *title, int lisu_num, n_list_store *list, const char **xpm, const char **xpm2)
+list_sub_window_create(struct SubWin *d, const char *title, int lisu_num, n_list_store *list, const char *icon, const char *icon2)
 {
   GtkWidget *swin;
   struct obj_list_data *data;
@@ -1514,11 +1566,11 @@ list_sub_window_create(struct SubWin *d, const char *title, int lisu_num, n_list
   data = list_widget_create(d, lisu_num, list, d->type != TypeFileWin, &swin);
   d->data.data = data;
 
-  return sub_window_create(d, title, swin, xpm, xpm2);
+  return sub_window_create(d, title, swin, icon, icon2);
 }
 
 GtkWidget *
-tree_sub_window_create(struct SubWin *d, const char *title, int page_num, int *lisu_num, n_list_store **list, GtkWidget **icons, const char **xpm, const char **xpm2)
+tree_sub_window_create(struct SubWin *d, const char *title, int page_num, int *lisu_num, n_list_store **list, GtkWidget **icons, const char *icon, const char *icon2)
 {
   GtkWidget *tab, *swin;
   int i;
@@ -1544,7 +1596,7 @@ tree_sub_window_create(struct SubWin *d, const char *title, int page_num, int *l
   }
   gtk_notebook_set_current_page(GTK_NOTEBOOK(tab), 0);
 
-  return sub_window_create(d, title, tab, xpm, xpm2);
+  return sub_window_create(d, title, tab, icon, icon2);
 }
 
 gboolean
@@ -1668,42 +1720,59 @@ ev_popup_menu(GtkWidget *w, gpointer client_data)
   return TRUE;
 }
 
-GtkWidget *
-sub_win_create_popup_menu(struct obj_list_data *d, int n, struct subwin_popup_list *list, GCallback cb)
+static GtkWidget *
+create_popup_menu_sub(struct obj_list_data *d, int top, struct subwin_popup_list *list)
 {
-  GtkWidget *menu, *item;
-  int i = 0;
-
-  if (d->popup_item)
-    g_free(d->popup_item);
-
-  d->popup_item = g_malloc(sizeof(GtkWidget *) * n);
-
+  GtkWidget *menu, *item, *submenu;
+  int i;
   menu = gtk_menu_new();
 
-  for (i = 0; i < n; i++) {
+  for (i = 0; list[i].type != POP_UP_MENU_ITEM_TYPE_END; i++) {
     switch (list[i].type) {
     case POP_UP_MENU_ITEM_TYPE_NORMAL:
-      if (list[i].use_stock) {
-	item = gtk_image_menu_item_new_from_stock(list[i].title, list[i].accel_group);
-      } else {
-	item = gtk_menu_item_new_with_mnemonic(_(list[i].title));
-      }
+      item = gtk_menu_item_new_with_mnemonic(_(list[i].title));
       g_signal_connect(item, "activate", list[i].func, d);
       break;
     case POP_UP_MENU_ITEM_TYPE_CHECK:
       item = gtk_check_menu_item_new_with_mnemonic(_(list[i].title));
       g_signal_connect(item, "toggled", list[i].func, d);
       break;
+    case POP_UP_MENU_ITEM_TYPE_MENU:
+      item = gtk_menu_item_new_with_mnemonic(_(list[i].title));
+      submenu = create_popup_menu_sub(d, FALSE, list[i].submenu);
+      gtk_menu_item_set_submenu(GTK_MENU_ITEM(item), submenu);
+      break;
+    case POP_UP_MENU_ITEM_TYPE_RECENT_DATA:
+      item = gtk_menu_item_new_with_mnemonic(_(list[i].title));
+      submenu = create_recent_menu(RECENT_TYPE_DATA);
+      gtk_menu_item_set_submenu(GTK_MENU_ITEM(item), submenu);
+      break;
     case POP_UP_MENU_ITEM_TYPE_SEPARATOR:
     default:
       item = gtk_separator_menu_item_new();
       break;
     }
-    d->popup_item[i] = item;
+    if (top) {
+      d->popup_item[i] = item;
+    }
     gtk_menu_shell_append(GTK_MENU_SHELL(menu), item);
   }
 
+  return menu;
+}
+
+GtkWidget *
+sub_win_create_popup_menu(struct obj_list_data *d, int n, struct subwin_popup_list *list, GCallback cb)
+{
+  GtkWidget *menu;
+
+  if (d->popup_item)
+    g_free(d->popup_item);
+
+  d->popup_item = g_malloc(sizeof(GtkWidget *) * n);
+
+  menu = create_popup_menu_sub(d, TRUE, list);
+
   d->popup = menu;
   gtk_widget_show_all(menu);
   gtk_menu_attach_to_widget(GTK_MENU(menu), GTK_WIDGET(d->text), NULL);
