@@ -10,11 +10,46 @@
 #include "ox11menu.h"
 #include "x11menu.h"
 #include "x11gui.h"
+#include "dir_defs.h"
+
+GtkWidget *
+create_image_from_file(const char *file)
+{
+  GtkWidget *img;
+#ifdef WINDOWS
+    char *str;
+    str = g_strdup_printf("%s%s", PIXMAPDIR, file);
+    img = gtk_image_new_from_file(str);
+    g_free(str);
+#else
+    img = gtk_image_new_from_file(file);
+#endif
+    return img;
+}
+
+void
+set_button_icon(GtkWidget *w, const char *icon_name)
+{
+#if ! GTK_CHECK_VERSION(3, 12, 0)
+  GtkWidget *icon;
+  icon = gtk_image_new_from_icon_name(icon_name, GTK_ICON_SIZE_BUTTON);
+  gtk_button_set_image(GTK_BUTTON(w), icon);
+#endif
+}
 
 void
 set_widget_margin(GtkWidget *w, int margin_pos)
 {
 #if GTK_CHECK_VERSION(3, 0, 0)
+#if GTK_CHECK_VERSION(3, 12, 0)
+  if (margin_pos & WIDGET_MARGIN_LEFT) {
+    gtk_widget_set_margin_start(w, 4);
+  }
+
+  if (margin_pos & WIDGET_MARGIN_RIGHT) {
+    gtk_widget_set_margin_end(w, 4);
+  }
+#else
   if (margin_pos & WIDGET_MARGIN_LEFT) {
     gtk_widget_set_margin_left(w, 4);
   }
@@ -22,6 +57,7 @@ set_widget_margin(GtkWidget *w, int margin_pos)
   if (margin_pos & WIDGET_MARGIN_RIGHT) {
     gtk_widget_set_margin_right(w, 4);
   }
+#endif
 
   if (margin_pos & WIDGET_MARGIN_BOTTOM) {
     gtk_widget_set_margin_bottom(w, 4);
@@ -305,7 +341,7 @@ create_file_entry_with_cb(GCallback cb, gpointer data)
 
   w = create_text_entry(TRUE, TRUE);
 
-  gtk_entry_set_icon_from_stock(GTK_ENTRY(w), GTK_ENTRY_ICON_SECONDARY, GTK_STOCK_OPEN);
+  gtk_entry_set_icon_from_icon_name(GTK_ENTRY(w), GTK_ENTRY_ICON_SECONDARY, "document-open");
   g_signal_connect(w, "icon-release", cb, data);
 
   return w;
@@ -360,13 +396,12 @@ create_direction_entry(void)
   GtkWidget *w;
 
   w = create_spin_entry_type(SPIN_BUTTON_TYPE_ANGLE, FALSE, TRUE);
-#if GTK_CHECK_VERSION(3, 4, 0)
-  gtk_widget_set_size_request(w, NUM_ENTRY_WIDTH * 1.2, -1);
-#else
-  gtk_widget_set_size_request(w, NUM_ENTRY_WIDTH * 1.5, -1);
+  gtk_entry_set_width_chars(GTK_ENTRY(w), NUM_ENTRY_WIDTH);
+#if GTK_CHECK_VERSION(3, 12, 0)
+  gtk_entry_set_max_width_chars(GTK_ENTRY(w), NUM_ENTRY_WIDTH);
 #endif
-  gtk_entry_set_icon_from_stock(GTK_ENTRY(w), GTK_ENTRY_ICON_SECONDARY, GTK_STOCK_GO_UP);
-  gtk_entry_set_icon_from_stock(GTK_ENTRY(w), GTK_ENTRY_ICON_PRIMARY, GTK_STOCK_GO_DOWN);
+  gtk_entry_set_icon_from_icon_name(GTK_ENTRY(w), GTK_ENTRY_ICON_SECONDARY, "go-up");
+  gtk_entry_set_icon_from_icon_name(GTK_ENTRY(w), GTK_ENTRY_ICON_PRIMARY, "go-down");
   g_signal_connect(w, "icon-release", G_CALLBACK(direction_icon_released), NULL);
 
   return w;
@@ -380,11 +415,13 @@ create_text_entry(int set_default_size, int set_default_action)
   GtkWidget *w;
 
   w = gtk_entry_new();
-  if (set_default_size)
-    gtk_widget_set_size_request(w, NUM_ENTRY_WIDTH, -1);
+  if (set_default_size) {
+    gtk_entry_set_width_chars(GTK_ENTRY(w), NUM_ENTRY_WIDTH);
+  }
 
-  if (set_default_action)
+  if (set_default_action) {
     gtk_entry_set_activates_default(GTK_ENTRY(w), TRUE);
+  }
 
   return w;
 }
@@ -536,11 +573,16 @@ _create_spin_entry(enum SPIN_BUTTON_TYPE type, double min, double max,
   gtk_spin_button_set_numeric(GTK_SPIN_BUTTON(w), FALSE);
   gtk_spin_button_set_digits(GTK_SPIN_BUTTON(w), (numeric) ? 0 : 2);
 
-  if (set_default_size)
-    gtk_widget_set_size_request(w, NUM_ENTRY_WIDTH, -1);
+  if (set_default_size) {
+    gtk_entry_set_width_chars(GTK_ENTRY(w), NUM_ENTRY_WIDTH);
+#if GTK_CHECK_VERSION(3, 12, 0)
+    gtk_entry_set_max_width_chars(GTK_ENTRY(w), NUM_ENTRY_WIDTH);
+#endif
+  }
 
-  if (set_default_action)
+  if (set_default_action) {
     gtk_entry_set_activates_default(GTK_ENTRY(w), TRUE);
+  }
 
   g_object_set_data(G_OBJECT(w), "user-data", GINT_TO_POINTER(type));
 
@@ -859,39 +901,156 @@ text_view_size_allocate(GtkWidget*widget, GdkRectangle *allocation, gpointer use
   set_scroll_visibility(scl);
 }
 
+#if GTK_CHECK_VERSION(3, 16, 0)
+void
+set_widget_font(GtkWidget *w, const char *font)
+{
+  GtkCssProvider *css_provider;
+  GError *error;
+  char *css_str;
+  PangoFontDescription *desc;
+  const char *family, *style_str, *unit;
+  PangoStyle style;
+  PangoWeight weight;
+  int weight_val, size;
+
+  desc = pango_font_description_from_string(font);
+  if (desc == NULL) {
+    return;
+  }
+
+  family = pango_font_description_get_family(desc);
+  style = pango_font_description_get_style(desc);
+  size = pango_font_description_get_size(desc);
+  weight = pango_font_description_get_weight(desc);
+  switch (style) {
+  case PANGO_STYLE_NORMAL:
+    style_str = "normal";
+    break;
+  case PANGO_STYLE_OBLIQUE:
+    style_str = "oblique";
+    break;
+ case PANGO_STYLE_ITALIC:
+    style_str = "italic";
+    break;
+  default:
+    style_str = "normal";
+    break;
+  }
+
+  switch (weight) {
+  case PANGO_WEIGHT_THIN:
+    weight_val = 100;
+    break;
+  case PANGO_WEIGHT_ULTRALIGHT:
+    weight_val = 200;
+    break;
+  case PANGO_WEIGHT_LIGHT:
+    weight_val = 300;
+    break;
+  case PANGO_WEIGHT_SEMILIGHT:
+    weight_val = 350;
+    break;
+  case PANGO_WEIGHT_BOOK:
+    weight_val = 380;
+    break;
+  case PANGO_WEIGHT_NORMAL:
+    weight_val = 400;
+    break;
+  case PANGO_WEIGHT_MEDIUM:
+    weight_val = 500;
+    break;
+  case PANGO_WEIGHT_SEMIBOLD:
+    weight_val = 600;
+    break;
+  case PANGO_WEIGHT_BOLD:
+    weight_val = 700;
+    break;
+  case PANGO_WEIGHT_ULTRABOLD:
+    weight_val = 800;
+    break;
+  case PANGO_WEIGHT_HEAVY:
+    weight_val = 900;
+    break;
+  case PANGO_WEIGHT_ULTRAHEAVY:
+    weight_val = 1000;
+    break;
+  default:
+    weight_val = 400;
+    break;
+  }
+
+  if (pango_font_description_get_size_is_absolute(desc)) {
+    unit = "px";
+  } else {
+    unit = "pt";
+  }
+
+  css_str = g_strdup_printf("* {font: %s %d %d%s \"%s\";}",
+			    style_str,
+			    weight_val,
+			    size / PANGO_SCALE,
+			    unit,
+			    family ? family : "");
+  pango_font_description_free(desc);
+  if (css_str == NULL) {
+    return;
+  }
+
+  css_provider = gtk_css_provider_new();
+  if (css_provider == NULL) {
+    return;
+  }
+
+  error = NULL;
+  gtk_css_provider_load_from_data(css_provider, css_str, -1, &error);
+  g_free(css_str);
+  if (error == NULL) {
+    gtk_style_context_add_provider(gtk_widget_get_style_context(w),
+				   GTK_STYLE_PROVIDER(css_provider),
+				   GTK_STYLE_PROVIDER_PRIORITY_USER);
+  }
+}
+
+#else  /* GTK_CHECK_VERSION(3, 16, 0) */
+
+#define LINE_NUMBER_R 0xCC00
+#define LINE_NUMBER_G 0xCC00
+#define LINE_NUMBER_B 0xCC00
+
 static void
-set_linumber_color(GtkWidget *w, guint r, guint g, guint b)
+set_linumber_color(GtkWidget *w)
 {
 #if GTK_CHECK_VERSION(3, 0, 0)
   GdkRGBA col;
 
-  col.red   = r * 1.0 / 0xFFFF;
-  col.green = g * 1.0 / 0xFFFF;
-  col.blue  = b * 1.0 / 0xFFFF;
+  col.red   = LINE_NUMBER_R * 1.0 / 0xFFFF;
+  col.green = LINE_NUMBER_G * 1.0 / 0xFFFF;
+  col.blue  = LINE_NUMBER_B * 1.0 / 0xFFFF;
   col.alpha = 1.0;
 
-  gtk_widget_override_background_color(w, GTK_STATE_NORMAL, &col);
-  gtk_widget_override_background_color(w, GTK_STATE_ACTIVE, &col);
-  gtk_widget_override_background_color(w, GTK_STATE_PRELIGHT, &col);
-  gtk_widget_override_background_color(w, GTK_STATE_SELECTED, &col);
-  gtk_widget_override_background_color(w, GTK_STATE_INSENSITIVE, &col);
+  gtk_widget_override_background_color(w, GTK_STATE_FLAG_NORMAL, &col);
+  gtk_widget_override_background_color(w, GTK_STATE_FLAG_ACTIVE, &col);
+  gtk_widget_override_background_color(w, GTK_STATE_FLAG_PRELIGHT, &col);
+  gtk_widget_override_background_color(w, GTK_STATE_FLAG_SELECTED, &col);
+  gtk_widget_override_background_color(w, GTK_STATE_FLAG_INSENSITIVE, &col);
 
   col.red   = 0;
   col.green = 0;
   col.blue  = 0;
   col.alpha = 1.0;
 
-  gtk_widget_override_color(w, GTK_STATE_NORMAL, &col);
-  gtk_widget_override_color(w, GTK_STATE_ACTIVE, &col);
-  gtk_widget_override_color(w, GTK_STATE_PRELIGHT, &col);
-  gtk_widget_override_color(w, GTK_STATE_SELECTED, &col);
-  gtk_widget_override_color(w, GTK_STATE_INSENSITIVE, &col);
+  gtk_widget_override_color(w, GTK_STATE_FLAG_NORMAL, &col);
+  gtk_widget_override_color(w, GTK_STATE_FLAG_ACTIVE, &col);
+  gtk_widget_override_color(w, GTK_STATE_FLAG_PRELIGHT, &col);
+  gtk_widget_override_color(w, GTK_STATE_FLAG_SELECTED, &col);
+  gtk_widget_override_color(w, GTK_STATE_FLAG_INSENSITIVE, &col);
 #else
   GdkColor col;
 
-  col.red = r;
-  col.green = g;
-  col.blue = b;
+  col.red = LINE_NUMBER_R;
+  col.green = LINE_NUMBER_G;
+  col.blue = LINE_NUMBER_B;
 
   gtk_widget_modify_base(w, GTK_STATE_NORMAL, &col);
   gtk_widget_modify_base(w, GTK_STATE_ACTIVE, &col);
@@ -913,6 +1072,8 @@ set_linumber_color(GtkWidget *w, guint r, guint g, guint b)
   gtk_widget_set_sensitive(w, FALSE);
 }
 
+#endif	/* ! GTK_CHECK_VERSION(3, 16, 0) */
+
 #if GTK_CHECK_VERSION(3, 0, 0)
 static void (* get_preferred_width_org) (GtkWidget *w, gint *min, gint *natulal);
 static void (* get_preferred_height_org) (GtkWidget *w, gint *min, gint *natulal);
@@ -946,8 +1107,15 @@ create_text_view_with_line_number(GtkWidget **v)
 
   buf = gtk_text_buffer_new(NULL);
   ln = gtk_text_view_new_with_buffer(buf);
+#if GTK_CHECK_VERSION(3, 12, 0)
+  gtk_widget_set_margin_end(ln, 4);
+#endif
 
-  set_linumber_color(ln, 0xCC00, 0xCC00, 0xCC00);
+#if GTK_CHECK_VERSION(3, 16, 0)
+  gtk_widget_set_name(ln, LINE_NUMBER_WIDGET_NAME);
+#else
+  set_linumber_color(ln);
+#endif
 
   g_object_set_data(G_OBJECT(view), "line_number", ln);
 
@@ -1067,9 +1235,14 @@ text_view_with_line_number_set_text(GtkWidget *view, const gchar *str)
 void
 text_view_with_line_number_set_font(GtkWidget *view, const gchar *font)
 {
+#if ! GTK_CHECK_VERSION(3, 16, 0)
   PangoFontDescription *desc;
+#endif
   GtkWidget *ln;
 
+#if GTK_CHECK_VERSION(3, 16, 0)
+  set_widget_font(view, font);
+#else  /* GTK_CHECK_VERSION(3, 16, 0) */
   desc = pango_font_description_from_string(font);
 #if GTK_CHECK_VERSION(3, 0, 0)
   gtk_widget_override_font(view, NULL);
@@ -1078,13 +1251,19 @@ text_view_with_line_number_set_font(GtkWidget *view, const gchar *font)
   gtk_widget_modify_font(view, NULL);
   gtk_widget_modify_font(view, desc);
 #endif
+#endif	/* GTK_CHECK_VERSION(3, 16, 0) */
 
   ln = g_object_get_data(G_OBJECT(view), "line_number");
   if (ln == NULL) {
+#if ! GTK_CHECK_VERSION(3, 16, 0)
     pango_font_description_free(desc);
+#endif
     return;
   }
 
+#if GTK_CHECK_VERSION(3, 16, 0)
+  set_widget_font(ln, font);
+#else  /* GTK_CHECK_VERSION(3, 16, 0) */
 #if GTK_CHECK_VERSION(3, 0, 0)
   gtk_widget_override_font(ln, NULL);
   gtk_widget_override_font(ln, desc);
@@ -1094,6 +1273,7 @@ text_view_with_line_number_set_font(GtkWidget *view, const gchar *font)
 #endif
 
   pango_font_description_free(desc);
+#endif	/* GTK_CHECK_VERSION(3, 16, 0) */
 }
 
 enum SELECT_OBJ_COLOR_RESULT
