@@ -1,12 +1,10 @@
 #ifndef GTK_WIDGET_HEADER
 #define GTK_WIDGET_HEADER
 
+#include "object.h"
+
 #define SPIN_ENTRY_MAX 1000000
-#if GTK_CHECK_VERSION(3, 4, 0)
-#define NUM_ENTRY_WIDTH 160
-#else
-#define NUM_ENTRY_WIDTH 80
-#endif
+#define NUM_ENTRY_WIDTH 12
 
 enum SPIN_BUTTON_TYPE {
   SPIN_BUTTON_TYPE_WIDTH,
@@ -50,6 +48,9 @@ enum WIDGET_MARGIN {
 
 GtkWidget *create_spin_entry_type(enum SPIN_BUTTON_TYPE type, int set_default_size, int set_default_action);
 GtkWidget *create_spin_entry(int min, int max, int inc, int set_default_size, int set_default_action);
+
+void set_button_icon(GtkWidget *w, const char *icon_name);
+
 void spin_entry_set_val(GtkWidget *entry, int val);
 int spin_entry_get_val(GtkWidget *entry);
 void spin_entry_set_range(GtkWidget *w, int min, int max);
@@ -57,6 +58,7 @@ void spin_entry_set_inc(GtkWidget *w, int inc, int page);
 char *entry_get_filename(GtkWidget *w);
 int entry_set_filename(GtkWidget *w, char *filename);
 
+GtkWidget *create_image_from_file(const char *file);
 GtkWidget *create_color_button(GtkWidget *win);
 GtkWidget *create_text_entry(int set_default_size, int set_default_action);
 GtkWidget *create_file_entry(struct objlist *obj);
@@ -77,5 +79,8 @@ void combo_box_create_mark(GtkWidget *cbox, GtkTreeIter *parent, int col_id, int
 enum SELECT_OBJ_COLOR_RESULT select_obj_color(struct objlist *obj, int id, enum OBJ_FIELD_COLOR_TYPE type);
 void set_widget_margin(GtkWidget *w, int margin_pos);
 void set_scale_mark(GtkWidget *scale, GtkPositionType pos, int start, int inc);
+#if GTK_CHECK_VERSION(3, 16, 0)
+void set_widget_font(GtkWidget *w, const char *font);
+#endif
 
 #endif
