@@ -52,7 +52,7 @@
 #include "gtk_widget.h"
 #include "gtk_subwin.h"
 
-#include "main.h"
+#include "init.h"
 #include "ogra2cairo.h"
 #include "ogra2x11.h"
 #include "ox11menu.h"
@@ -330,8 +330,6 @@ static struct menu_config *MenuConfigArrray[] = {
 
 static NHASH MenuConfigHash = NULL;
 
-#define BUF_SIZE 64
-
 #if ! GTK_CHECK_VERSION(3, 4, 0)
 static void
 get_palette(void)
@@ -390,9 +388,8 @@ add_str_with_int_to_array(struct menu_config *cfg, struct narray *conf)
 {
   char *buf;
 
-  buf = (char *) g_malloc(BUF_SIZE);
+  buf = g_strdup_printf("%s=%d", cfg->name, * (int *) cfg->data);
   if (buf) {
-    snprintf(buf, BUF_SIZE, "%s=%d", cfg->name, * (int *) cfg->data);
     arrayadd(conf, &buf);
   }
 }
@@ -407,12 +404,11 @@ add_child_geometry_to_array(struct menu_config *cfg, struct narray *conf)
   stat = cfg->data;
   data = stat->stat;
 
-  buf = (char *) g_malloc(BUF_SIZE);
+  buf = g_strdup_printf("%s=%d,%d,%d,%d,%d",
+			cfg->name, *data[0], *data[1], *data[2], *data[3], *data[4]);
   if (buf) {
     sub_window_save_geometry(stat->win);
     sub_window_save_visibility(stat->win);
-    snprintf(buf, BUF_SIZE, "%s=%d,%d,%d,%d,%d",
-	     cfg->name, *data[0], *data[1], *data[2], *data[3], *data[4]);
     arrayadd(conf, &buf);
   }
 }
@@ -430,12 +426,11 @@ add_geometry_to_array(struct menu_config *cfg, struct narray *conf)
   Menulocal.menuwidth = w;
   Menulocal.menuheight = h;
 
-  buf = (char *) g_malloc(BUF_SIZE);
+  buf = g_strdup_printf("%s=%d,%d,%d,%d",
+			cfg->name,
+			Menulocal.menux, Menulocal.menuy,
+			Menulocal.menuwidth, Menulocal.menuheight);
   if (buf) {
-    snprintf(buf, BUF_SIZE, "%s=%d,%d,%d,%d",
-	     cfg->name,
-	     Menulocal.menux, Menulocal.menuy,
-	     Menulocal.menuwidth, Menulocal.menuheight);
     arrayadd(conf, &buf);
   }
 }
@@ -444,13 +439,12 @@ static void
 add_color_to_array(struct menu_config *cfg, struct narray *conf)
 {
   char *buf;
-  buf = (char *) g_malloc(BUF_SIZE);
+  buf = g_strdup_printf("%s=%02x%02x%02x",
+			cfg->name,
+			(int) (Menulocal.bg_r * 255),
+			(int) (Menulocal.bg_g * 255),
+			(int) (Menulocal.bg_b * 255));
   if (buf) {
-    snprintf(buf, BUF_SIZE, "%s=%02x%02x%02x",
-	     cfg->name,
-	     (int) (Menulocal.bg_r * 255),
-	     (int) (Menulocal.bg_g * 255),
-	     (int) (Menulocal.bg_b * 255));
     arrayadd(conf, &buf);
   }
 }
@@ -1009,7 +1003,7 @@ void
 menuadddrawrable(struct objlist *parent, struct narray *drawrable)
 {
   struct objlist *ocur;
-  char *name;
+  const char *name;
 
   ocur = chkobjroot();
   while (ocur) {
@@ -1090,8 +1084,6 @@ menulocal_finalize(void)
 
   arraydel2(&Menulocal.drawrable);
 
-  Menulocal.ngpfilelist = NULL;
-
   g_free(Menulocal.fileopendir);
   Menulocal.fileopendir = NULL;
 
@@ -1148,7 +1140,6 @@ menuinit(struct objlist *obj, N_VALUE *inst, N_VALUE *rval, int argc, char **arg
   Menulocal.expand = 1;
   Menulocal.expanddir = g_strdup("./");
   Menulocal.loadpath = SAVE_PATH_FULL;
-  Menulocal.ngpfilelist = gtk_recent_manager_get_default();
   Menulocal.GRAobj = chkobject("gra");
   Menulocal.hist_size = 1000;
   Menulocal.info_size = 1000;
@@ -1291,7 +1282,7 @@ mgtkputstdout(const char *s)
 }
 
 int
-mgtkprintfstderr(char *fmt, ...)
+mgtkprintfstderr(const char *fmt, ...)
 {
   int len;
   char buf[1024];
@@ -1305,7 +1296,7 @@ mgtkprintfstderr(char *fmt, ...)
 }
 
 int
-mgtkprintfstdout(char *fmt, ...)
+mgtkprintfstdout(const char *fmt, ...)
 {
   int len;
   char buf[1024];
@@ -1637,7 +1628,8 @@ static int
 mx_get_focused(struct objlist *obj, N_VALUE *inst, N_VALUE *rval, int argc, char **argv)
 {
   int num, i, id;
-  char *name, *ptr;
+  const char *name;
+  char *ptr;
   struct narray *oarray, *sarray;
   struct Viewer *d;
   struct FocusObj **focus;
@@ -1796,7 +1788,7 @@ mx_show_win(struct objlist *obj, N_VALUE *inst, N_VALUE *rval, int argc, char **
 
   win = * (unsigned int *) (argv[2]);
 
-  window_action_set_active(win, TRUE);
+  set_subwindow_state(win, SUBWIN_STATE_SHOW);
 
   return 0;
 }
@@ -1817,7 +1809,7 @@ mx_hide_win(struct objlist *obj, N_VALUE *inst, N_VALUE *rval, int argc, char **
 
   win = * (unsigned int *) (argv[2]);
 
-  window_action_set_active(win, FALSE);
+  set_subwindow_state(win, SUBWIN_STATE_HIDE);
 
   return 0;
 }
@@ -1838,18 +1830,7 @@ mx_toggle_win(struct objlist *obj, N_VALUE *inst, N_VALUE *rval, int argc, char
 
   win = * (int *) (argv[2]);
 
-  window_action_toggle(win);
-
-  return 0;
-}
-
-static int
-mx_get_ui(struct objlist *obj, N_VALUE *inst, N_VALUE *rval, int argc, char **argv)
-{
-  if (rval->str) {
-    g_free(rval->str);
-  }
-  rval->str = get_ui_definition();
+  set_subwindow_state(win, SUBWIN_STATE_TOGGLE);
 
   return 0;
 }
@@ -1857,6 +1838,27 @@ mx_get_ui(struct objlist *obj, N_VALUE *inst, N_VALUE *rval, int argc, char **ar
 static int
 mx_get_accel_map(struct objlist *obj, N_VALUE *inst, N_VALUE *rval, int argc, char **argv)
 {
+#if USE_GTK_BUILDER
+  char **actions, **accels;
+  int i, j;
+  GString *str;
+
+  if (rval->str) {
+    g_free(rval->str);
+  }
+  rval->str = NULL;
+
+  str = g_string_new("");
+  actions = gtk_application_list_action_descriptions(GtkApp);
+  for (i = 0; actions[i]; i++) {
+    accels = gtk_application_get_accels_for_action(GtkApp, actions[i]);
+    for (j = 0; accels[j]; j++) {
+      g_string_append_printf(str, "%s %s\n", actions[i], accels[j]);
+    }
+    g_strfreev(accels);
+  }
+  g_strfreev(actions);
+#else
   FILE *fp;
   int fd;
   char buf[1024], *ptr;
@@ -1885,6 +1887,7 @@ mx_get_accel_map(struct objlist *obj, N_VALUE *inst, N_VALUE *rval, int argc, ch
     g_string_append(str, buf);
   }
   fclose(fp);
+#endif
 
   rval->str = g_string_free(str, FALSE);
 
@@ -1970,7 +1973,7 @@ mx_show_lib_version(struct objlist *obj, N_VALUE *inst, N_VALUE *rval, int argc,
 	       h,
 	       pango_version_string());
 
-#ifdef HAVE_READLINE_READLINE_H
+#ifdef RL_VERSION_MAJOR
   g_string_append(str, "\n");
   g_string_append_printf(str, "%sreadline\n"
 	       "%s compile: %d.%d\n"
@@ -2295,7 +2298,6 @@ static struct objtable gtkmenu[] = {
   {"show_window", NVFUNC, NREAD | NEXEC, mx_show_win, "i", 0},
   {"hide_window", NVFUNC, NREAD | NEXEC, mx_hide_win, "i", 0},
   {"toggle_window", NVFUNC, NREAD | NEXEC, mx_toggle_win, "i", 0},
-  {"get_ui", NSFUNC, NREAD | NEXEC, mx_get_ui, "", 0},
   {"get_accel_map", NSFUNC, NREAD | NEXEC, mx_get_accel_map, "", 0},
   {"lib_version", NSFUNC, NREAD | NEXEC, mx_show_lib_version, NULL, 0},
   {"focus", NVFUNC, NREAD | NEXEC, mx_focus_obj, "o", 0},
