@@ -120,7 +120,6 @@ struct menulocal
   char *fileopendir, *graphloaddir, *expanddir, *coordwin_font, *infowin_font, *file_preview_font;
   int expand, loadpath, expandtofullpath, changedirectory, savehistory;
   int savepath, savewithdata, savewithmerge;
-  GtkRecentManager *ngpfilelist;
   int scriptconsole, addinconsole;
   int statusbar, sidebar, ruler, scrollbar, ctoolbar, ptoolbar, show_cross, showtip, preserve_width;
   int hist_size, info_size;
@@ -170,11 +169,11 @@ void mx_dellist(struct objlist *obj, N_VALUE *inst, int deln);
 void mgtkdisplaydialog(const char *str);
 void mgtkdisplaystatus(const char *str);
 int mgtkputstderr(const char *s);
-int mgtkprintfstderr(char *fmt, ...);
+int mgtkprintfstderr(const char *fmt, ...);
 int mgtkinterrupt(void);
 int mgtkinputyn(const char *mes);
 int mgtkputstdout(const char *s);
-int mgtkprintfstdout(char *fmt, ...);
+int mgtkprintfstdout(const char *fmt, ...);
 void initwindowconfig(void);
 int mgtkwindowconfig(void);
 void menuadddrawrable(struct objlist *parent, struct narray *drawrable);
