@@ -64,19 +64,25 @@ static n_list_store Alist[] = {
   {N_("dir"),  G_TYPE_DOUBLE,  TRUE, TRUE,  "direction",        0,          36000, 100, 1500},
   {N_("len"),  G_TYPE_DOUBLE,  TRUE, TRUE,  "length", - SPIN_ENTRY_MAX, SPIN_ENTRY_MAX, 100, 1000},
   {"^#",       G_TYPE_INT,     TRUE, FALSE, "oid"},
+  {"num_math", G_TYPE_INT,     FALSE, FALSE, "num_math"},
 };
 
-#define AXIS_WIN_COL_NUM (sizeof(Alist)/sizeof(*Alist))
-#define AXIS_WIN_COL_OID (AXIS_WIN_COL_NUM - 1)
-#define AXIS_WIN_COL_HIDDEN 0
-#define AXIS_WIN_COL_ID     1
-#define AXIS_WIN_COL_NAME   2
-#define AXIS_WIN_COL_MIN    3
-#define AXIS_WIN_COL_MAX    4
-#define AXIS_WIN_COL_INC    5
-#define AXIS_WIN_COL_TYPE   6
-#define AXIS_WIN_COL_X      7
-#define AXIS_WIN_COL_Y      8
+enum {
+  AXIS_WIN_COL_HIDDEN,
+  AXIS_WIN_COL_ID,
+  AXIS_WIN_COL_NAME,
+  AXIS_WIN_COL_MIN,
+  AXIS_WIN_COL_MAX,
+  AXIS_WIN_COL_INC,
+  AXIS_WIN_COL_TYPE,
+  AXIS_WIN_COL_X,
+  AXIS_WIN_COL_Y,
+  AXIS_WIN_COL_DIR,
+  AXIS_WIN_COL_LEN,
+  AXIS_WIN_COL_OID,
+  AXIS_WIN_COL_MATH,
+  AXIS_WIN_COL_NUM,
+};
 
 static void axiswin_scale_clear(GtkMenuItem *item, gpointer user_data);
 static void axis_delete_popup_func(GtkMenuItem *w, gpointer client_data);
@@ -85,28 +91,38 @@ static void AxisWinAxisUp(GtkWidget *w, gpointer client_data);
 static void AxisWinAxisDown(GtkWidget *w, gpointer client_data);
 static void AxisWinAxisLast(GtkWidget *w, gpointer client_data);
 
-static struct subwin_popup_list Popup_list[] = {
-  {N_("_Duplicate"),      G_CALLBACK(list_sub_window_copy), FALSE, NULL, POP_UP_MENU_ITEM_TYPE_NORMAL},
-  {GTK_STOCK_DELETE,      G_CALLBACK(axis_delete_popup_func), TRUE, NULL, POP_UP_MENU_ITEM_TYPE_NORMAL},
-  {NULL, NULL, 0, NULL, POP_UP_MENU_ITEM_TYPE_SEPARATOR},
-  {N_("_Focus"),          G_CALLBACK(list_sub_window_focus), FALSE, NULL, POP_UP_MENU_ITEM_TYPE_NORMAL},
-  {GTK_STOCK_CLEAR,       G_CALLBACK(axiswin_scale_clear), TRUE, NULL, POP_UP_MENU_ITEM_TYPE_NORMAL},
-  {GTK_STOCK_PROPERTIES,  G_CALLBACK(list_sub_window_update), TRUE, NULL, POP_UP_MENU_ITEM_TYPE_NORMAL},
-  {NULL, NULL, 0, NULL, POP_UP_MENU_ITEM_TYPE_SEPARATOR},
-  {GTK_STOCK_GOTO_TOP,    G_CALLBACK(AxisWinAxisTop), TRUE, NULL, POP_UP_MENU_ITEM_TYPE_NORMAL},
-  {GTK_STOCK_GO_UP,       G_CALLBACK(AxisWinAxisUp), TRUE, NULL, POP_UP_MENU_ITEM_TYPE_NORMAL},
-  {GTK_STOCK_GO_DOWN,     G_CALLBACK(AxisWinAxisDown), TRUE, NULL, POP_UP_MENU_ITEM_TYPE_NORMAL},
-  {GTK_STOCK_GOTO_BOTTOM, G_CALLBACK(AxisWinAxisLast), TRUE, NULL, POP_UP_MENU_ITEM_TYPE_NORMAL},
+static struct subwin_popup_list add_menu_list[] = {
+  {N_("_Frame graph"), G_CALLBACK(CmAxisNewFrame), NULL, POP_UP_MENU_ITEM_TYPE_NORMAL},
+  {N_("_Section graph"), G_CALLBACK(CmAxisNewSection), NULL, POP_UP_MENU_ITEM_TYPE_NORMAL},
+  {N_("_Cross graph"), G_CALLBACK(CmAxisNewCross), NULL, POP_UP_MENU_ITEM_TYPE_NORMAL},
+  {N_("Single _Axis"), G_CALLBACK(CmAxisNewSingle), NULL, POP_UP_MENU_ITEM_TYPE_NORMAL},
+  {NULL, NULL, NULL, POP_UP_MENU_ITEM_TYPE_END},
 };
 
-#define POPUP_ITEM_NUM (sizeof(Popup_list) / sizeof(*Popup_list))
+static struct subwin_popup_list Popup_list[] = {
+  {N_("_Add"),        NULL, add_menu_list, POP_UP_MENU_ITEM_TYPE_MENU},
+  {NULL, NULL, NULL,  POP_UP_MENU_ITEM_TYPE_SEPARATOR},
+  {N_("_Duplicate"),  G_CALLBACK(list_sub_window_copy), NULL, POP_UP_MENU_ITEM_TYPE_NORMAL},
+  {N_("_Delete"),     G_CALLBACK(axis_delete_popup_func), NULL, POP_UP_MENU_ITEM_TYPE_NORMAL},
+  {NULL, NULL, NULL, POP_UP_MENU_ITEM_TYPE_SEPARATOR},
+  {N_("_Focus"),      G_CALLBACK(list_sub_window_focus), NULL, POP_UP_MENU_ITEM_TYPE_NORMAL},
+  {N_("_Clear"),      G_CALLBACK(axiswin_scale_clear), NULL, POP_UP_MENU_ITEM_TYPE_NORMAL},
+  {N_("_Properties"), G_CALLBACK(list_sub_window_update), NULL, POP_UP_MENU_ITEM_TYPE_NORMAL},
+  {NULL, NULL, NULL, POP_UP_MENU_ITEM_TYPE_SEPARATOR},
+  {N_("_Top"),        G_CALLBACK(AxisWinAxisTop), NULL, POP_UP_MENU_ITEM_TYPE_NORMAL},
+  {N_("_Up"),         G_CALLBACK(AxisWinAxisUp), NULL, POP_UP_MENU_ITEM_TYPE_NORMAL},
+  {N_("_Down"),       G_CALLBACK(AxisWinAxisDown), NULL, POP_UP_MENU_ITEM_TYPE_NORMAL},
+  {N_("_Bottom"),     G_CALLBACK(AxisWinAxisLast), NULL, POP_UP_MENU_ITEM_TYPE_NORMAL},
+  {NULL, NULL, NULL, POP_UP_MENU_ITEM_TYPE_END},
+};
 
-#define POPUP_ITEM_TOP 7
-#define POPUP_ITEM_UP 8
-#define POPUP_ITEM_DOWN 9
-#define POPUP_ITEM_BOTTOM 10
+#define POPUP_ITEM_NUM (sizeof(Popup_list) / sizeof(*Popup_list) - 1)
+
+#define POPUP_ITEM_TOP 9
+#define POPUP_ITEM_UP 10
+#define POPUP_ITEM_DOWN 11
+#define POPUP_ITEM_BOTTOM 12
 
-#define ID_BUF_SIZE 16
 #define TITLE_BUF_SIZE 128
 
 static void axis_list_set_val(struct obj_list_data *d, GtkTreeIter *iter, int row);
@@ -576,14 +592,14 @@ SectionDialogGrid(GtkWidget *w, gpointer client_data)
   d = (struct SectionDialog *) client_data;
   if (*(d->IDG) == -1) {
     if ((*(d->IDG) = newobj(d->Obj2)) >= 0) {
-      if ((ref = (char *) g_malloc(ID_BUF_SIZE)) != NULL) {
-	getobj(d->Obj, "oid", d->IDX, 0, NULL, &oidx);
-	snprintf(ref, ID_BUF_SIZE, "axis:^%d", oidx);
+      getobj(d->Obj, "oid", d->IDX, 0, NULL, &oidx);
+      ref = g_strdup_printf("axis:^%d", oidx);
+      if (ref) {
 	putobj(d->Obj2, "axis_x", *(d->IDG), ref);
       }
-      if ((ref = (char *) g_malloc(ID_BUF_SIZE)) != NULL) {
-	getobj(d->Obj, "oid", d->IDY, 0, NULL, &oidy);
-	snprintf(ref, ID_BUF_SIZE, "axis:^%d", oidy);
+      getobj(d->Obj, "oid", d->IDY, 0, NULL, &oidy);
+      ref = g_strdup_printf("axis:^%d", oidy);
+      if (ref) {
 	putobj(d->Obj2, "axis_y", *(d->IDG), ref);
       }
       create = TRUE;
@@ -1184,7 +1200,7 @@ AxisDialogFile(GtkWidget *w, gpointer client_data)
 
   d = (struct AxisDialog *) client_data;
 
-  fobj = chkobject("file");
+  fobj = chkobject("data");
   if (fobj == NULL)
     return;
 
@@ -1287,7 +1303,7 @@ file_button_show(GtkWidget *widget, gpointer user_data)
   int n;
 
   if (file == NULL) {
-    file = chkobject("file");
+    file = chkobject("data");
   }
 
   if (file == NULL)
@@ -1344,11 +1360,11 @@ scale_tab_create(struct AxisDialog *d)
   hbox = gtk_hbox_new(FALSE, 12);
 #endif
 
-  w = gtk_button_new_from_stock(GTK_STOCK_CLEAR);
+  w = gtk_button_new_with_mnemonic(_("_Clear"));
   g_signal_connect(w, "clicked", G_CALLBACK(AxisDialogClear), d);
   gtk_box_pack_start(GTK_BOX(hbox), w, FALSE, FALSE, 0);
 
-  w = gtk_button_new_with_mnemonic(_("_File"));
+  w = gtk_button_new_with_mnemonic(_("_Data"));
   g_signal_connect(w, "clicked", G_CALLBACK(AxisDialogFile), d);
   g_signal_connect(w, "map", G_CALLBACK(file_button_show), NULL);
   gtk_box_pack_start(GTK_BOX(hbox), w, FALSE, FALSE, 4);
@@ -1365,7 +1381,7 @@ scale_tab_create(struct AxisDialog *d)
 
   w = combo_box_entry_create();
   add_widget_to_table(table, w, _("_Ref:"), FALSE, i++);
-  gtk_widget_set_size_request(w, NUM_ENTRY_WIDTH * 1.5, -1);
+  combo_box_entry_set_width(w, NUM_ENTRY_WIDTH);
   g_signal_connect(w, "changed", G_CALLBACK(AxisDialogRef), d);
   d->ref = w;
 
@@ -1498,7 +1514,7 @@ baseline_tab_create(GtkWidget *wi, struct AxisDialog *dd)
   d->baseline = w;
 
   w = combo_box_entry_create();
-  gtk_widget_set_size_request(w, NUM_ENTRY_WIDTH * 1.5, -1);
+  combo_box_entry_set_width(w, NUM_ENTRY_WIDTH);
   add_widget_to_table(table, w, _("Line _Style:"), TRUE, i++);
   d->style = w;
 
@@ -1694,12 +1710,12 @@ gauge_tab_create(GtkWidget *wi, struct AxisDialog *dd)
   d->gauge = w;
 
   w = create_text_entry(FALSE, TRUE);
-  gtk_widget_set_size_request(w, NUM_ENTRY_WIDTH * 3, -1);
+  gtk_entry_set_width_chars(GTK_ENTRY(w), NUM_ENTRY_WIDTH * 2);
   add_widget_to_table(table, w, _("_Min:"), TRUE, j++);
   d->min = w;
 
   w = create_text_entry(FALSE, TRUE);
-  gtk_widget_set_size_request(w, NUM_ENTRY_WIDTH * 3, -1);
+  gtk_entry_set_width_chars(GTK_ENTRY(w), NUM_ENTRY_WIDTH * 2);
   add_widget_to_table(table, w, _("_Max:"), TRUE, j++);
   d->max = w;
 
@@ -1847,6 +1863,9 @@ numbering_tab_set_value(struct AxisDialog *axis)
   if (SetObjFieldFromWidget(d->norm, axis->Obj, axis->Id, "num_auto_norm"))
     return 1;
 
+  if (SetObjFieldFromWidget(d->math, axis->Obj, axis->Id, "num_math"))
+    return 1;
+
   return 0;
 }
 
@@ -1908,6 +1927,8 @@ numbering_tab_setup_item(struct AxisDialog *axis, int id)
   SetWidgetFromObjField(d->no_zero, axis->Obj, id, "num_no_zero");
 
   SetWidgetFromObjField(d->norm, axis->Obj, id, "num_auto_norm");
+
+  SetWidgetFromObjField(d->math, axis->Obj, id, "num_math");
 }
 
 static void
@@ -2059,6 +2080,10 @@ numbering_tab_create(GtkWidget *wi, struct AxisDialog *dd)
   add_widget_to_table(table, w, NULL, FALSE, i++);
   d->no_zero = w;
 
+  w = create_text_entry(FALSE, TRUE);
+  add_widget_to_table(table, w, _("numbering _Math:"), TRUE, i++);
+  d->math = w;
+
   frame = gtk_frame_new(_("Format"));
   gtk_container_add(GTK_CONTAINER(frame), table);
   set_widget_margin(frame, WIDGET_MARGIN_RIGHT);
@@ -2199,13 +2224,13 @@ font_tab_create(GtkWidget *wi, struct AxisDialog *dd)
   btn_box = gtk_hbutton_box_new();
 #endif
   gtk_box_set_spacing(GTK_BOX(btn_box), 10);
-  w = gtk_check_button_new_with_label("gtk-bold");
-  gtk_button_set_use_stock(GTK_BUTTON(w), TRUE);
+  w = gtk_check_button_new_with_mnemonic(_("_Bold"));
+  set_button_icon(w, "format-text-bold");
   d->font_bold = w;
   gtk_box_pack_start(GTK_BOX(btn_box), w, FALSE, FALSE, 0);
 
-  w = gtk_check_button_new_with_label("gtk-italic");
-  gtk_button_set_use_stock(GTK_BUTTON(w), TRUE);
+  w = gtk_check_button_new_with_mnemonic(_("_Italic"));
+  set_button_icon(w, "format-text-italic");
   d->font_italic = w;
   gtk_box_pack_start(GTK_BOX(btn_box), w, FALSE, FALSE, 0);
 
@@ -2347,11 +2372,7 @@ position_tab_create(GtkWidget *wi, struct AxisDialog *dd)
   d->direction = w;
 
   w = combo_box_entry_create();
-#if GTK_CHECK_VERSION(3, 4, 0)
-  gtk_widget_set_size_request(w, NUM_ENTRY_WIDTH, -1);
-#else
-  gtk_widget_set_size_request(w, NUM_ENTRY_WIDTH * 2, -1);
-#endif
+  combo_box_entry_set_width(w, NUM_ENTRY_WIDTH);
   g_signal_connect(w, "changed", G_CALLBACK(AxisDialogRef), dd);
   add_widget_to_table(table, w, _("_Adjust:"), FALSE, i++);
   d->adjust = w;
@@ -2534,7 +2555,7 @@ AxisDialog(struct obj_list_data *data, int id, int user_data)
 }
 
 void
-CmAxisNewFrame(GtkAction *w, gpointer client_data)
+CmAxisNewFrame(void *w, gpointer client_data)
 {
   struct objlist *obj, *obj2;
   int idx, idy, idu, idr, idg, ret;
@@ -2590,7 +2611,7 @@ CmAxisNewFrame(GtkAction *w, gpointer client_data)
 }
 
 void
-CmAxisNewSection(GtkAction *w, gpointer client_data)
+CmAxisNewSection(void *w, gpointer client_data)
 {
   struct objlist *obj, *obj2;
   int idx, idy, idu, idr, idg, ret, oidx, oidy;
@@ -2631,13 +2652,13 @@ CmAxisNewSection(GtkAction *w, gpointer client_data)
   arraydel(&group);
   if (idg >= 0) {
     getobj(obj, "oid", idx, 0, NULL, &oidx);
-    if ((ref = (char *) g_malloc(ID_BUF_SIZE)) != NULL) {
-      snprintf(ref, ID_BUF_SIZE, "axis:^%d", oidx);
+    ref = g_strdup_printf("axis:^%d", oidx);
+    if (ref) {
       putobj(obj2, "axis_x", idg, ref);
     }
     getobj(obj, "oid", idy, 0, NULL, &oidy);
-    if ((ref = (char *) g_malloc(ID_BUF_SIZE)) != NULL) {
-      snprintf(ref, ID_BUF_SIZE, "axis:^%d", oidy);
+    ref = g_strdup_printf("axis:^%d", oidy);
+    if (ref) {
       putobj(obj2, "axis_y", idg, ref);
     }
   }
@@ -2657,7 +2678,7 @@ CmAxisNewSection(GtkAction *w, gpointer client_data)
 }
 
 void
-CmAxisNewCross(GtkAction *w, gpointer client_data)
+CmAxisNewCross(void *w, gpointer client_data)
 {
   struct objlist *obj;
   int idx, idy, ret;
@@ -2699,7 +2720,7 @@ CmAxisNewCross(GtkAction *w, gpointer client_data)
 }
 
 void
-CmAxisNewSingle(GtkAction *w, gpointer client_data)
+CmAxisNewSingle(void *w, gpointer client_data)
 {
   struct objlist *obj;
   int id, ret;
@@ -2720,7 +2741,7 @@ CmAxisNewSingle(GtkAction *w, gpointer client_data)
 }
 
 void
-CmAxisDel(GtkAction *w, gpointer client_data)
+CmAxisDel(void *w, gpointer client_data)
 {
   struct objlist *obj;
 
@@ -2744,7 +2765,7 @@ CmAxisDel(GtkAction *w, gpointer client_data)
 }
 
 void
-CmAxisUpdate(GtkAction *w, gpointer client_data)
+CmAxisUpdate(void *w, gpointer client_data)
 {
   struct objlist *obj;
   int i, ret;
@@ -2772,7 +2793,7 @@ CmAxisUpdate(GtkAction *w, gpointer client_data)
 }
 
 void
-CmAxisZoom(GtkAction *w, gpointer client_data)
+CmAxisZoom(void *w, gpointer client_data)
 {
   struct narray farray;
   struct objlist *obj;
@@ -2847,7 +2868,7 @@ axiswin_scale_clear(GtkMenuItem *item, gpointer user_data)
 }
 
 void
-CmAxisClear(GtkAction *w, gpointer client_data)
+CmAxisClear(void *w, gpointer client_data)
 {
   struct narray farray;
   struct objlist *obj;
@@ -2875,7 +2896,7 @@ CmAxisClear(GtkAction *w, gpointer client_data)
 }
 
 void
-CmAxisGridNew(GtkAction *w, gpointer client_data)
+CmAxisGridNew(void *w, gpointer client_data)
 {
   struct objlist *obj;
   int id, ret;
@@ -2895,7 +2916,7 @@ CmAxisGridNew(GtkAction *w, gpointer client_data)
 }
 
 void
-CmAxisGridDel(GtkAction *w, gpointer client_data)
+CmAxisGridDel(void *w, gpointer client_data)
 {
   struct narray farray;
   struct objlist *obj;
@@ -2921,7 +2942,7 @@ CmAxisGridDel(GtkAction *w, gpointer client_data)
 }
 
 void
-CmAxisGridUpdate(GtkAction *w, gpointer client_data)
+CmAxisGridUpdate(void *w, gpointer client_data)
 {
   struct narray farray;
   struct objlist *obj;
@@ -2984,6 +3005,7 @@ axis_list_set_val(struct obj_list_data *d, GtkTreeIter *iter, int row)
   unsigned int i;
   double min, max, inc;
   char buf[256], *valstr;
+  int style;
 
   for (i = 0; i < AXIS_WIN_COL_NUM; i++) {
     switch (i) {
@@ -3032,6 +3054,15 @@ axis_list_set_val(struct obj_list_data *d, GtkTreeIter *iter, int row)
       cx = ! cx;
       list_store_set_val(GTK_WIDGET(d->text), iter, i, Alist[i].type, &cx);
       break;
+    case AXIS_WIN_COL_MATH:
+      getobj(d->obj, Alist[i].name, row, 0, NULL, &valstr);
+      if (valstr) {
+	style = PANGO_STYLE_ITALIC;
+      } else {
+	style = PANGO_STYLE_NORMAL;
+      }
+      list_store_set_int(GTK_WIDGET(d->text), iter, i, style);
+      break;
     default:
       if (Alist[i].type == G_TYPE_DOUBLE) {
 	getobj(d->obj, Alist[i].name, row, 0, NULL, &cx);
@@ -3064,7 +3095,7 @@ check_axis_history(struct objlist *obj)
 }
 
 void
-CmAxisScaleUndo(GtkAction *w, gpointer client_data)
+CmAxisScaleUndo(void *w, gpointer client_data)
 {
   char *argv[1];
   struct objlist *obj;
@@ -3107,7 +3138,7 @@ popup_show_cb(GtkWidget *widget, gpointer user_data)
 
   sel = d->select;
   num = chkobjlastinst(d->obj);
-  for (i = 0; i < POPUP_ITEM_NUM; i++) {
+  for (i = 1; i < POPUP_ITEM_NUM; i++) {
     switch (i) {
     case POPUP_ITEM_TOP:
     case POPUP_ITEM_UP:
@@ -3135,8 +3166,10 @@ pos_edited_common(struct obj_list_data *d, int id, char *str, enum CHANGE_DIR di
   double val;
   char *argv[3];
 
-  if (str == NULL || id < 0)
+  if (str == NULL || id < 0) {
+    menu_lock(FALSE);
     return;
+  }
 
   switch (dir) {
   case CHANGE_DIR_X:
@@ -3148,14 +3181,16 @@ pos_edited_common(struct obj_list_data *d, int id, char *str, enum CHANGE_DIR di
   }
 
   ecode = str_calc(str, &val, NULL, NULL);
+  menu_lock(FALSE);
   if (ecode || val != val || val == HUGE_VAL || val == - HUGE_VAL) {
     return;
   }
 
   pos2 = nround(val * 100);
 
-  if (pos1 == pos2)
+  if (pos1 == pos2) {
     return;
+  }
 
   switch (dir) {
   case CHANGE_DIR_X:
@@ -3187,8 +3222,6 @@ pos_x_edited(GtkCellRenderer *cell_renderer, gchar *path, gchar *str, gpointer u
   struct obj_list_data *d;
   int sel;
 
-  menu_lock(FALSE);
-
   d = (struct obj_list_data *) user_data;
 
   sel = list_store_get_selected_int(GTK_WIDGET(d->text), COL_ID);
@@ -3202,8 +3235,6 @@ pos_y_edited(GtkCellRenderer *cell_renderer, gchar *path, gchar *str, gpointer u
   struct obj_list_data *d;
   int sel;
 
-  menu_lock(FALSE);
-
   d = (struct obj_list_data *) user_data;
 
   sel = list_store_get_selected_int(GTK_WIDGET(d->text), COL_ID);
@@ -3216,18 +3247,22 @@ axis_prm_edited_common(struct obj_list_data *d, char *field, gchar *str)
 {
   int sel, num;
 
-  menu_lock(FALSE);
-
   sel = list_store_get_selected_int(GTK_WIDGET(d->text), COL_ID);
   num = chkobjlastinst(d->obj);
 
-  if (sel < 0 || sel > num)
+  if (sel < 0 || sel > num) {
+    menu_lock(FALSE);
     return;
+  }
 
   axis_scale_push(d->obj, sel);
 
-  if (chk_sputobjfield(d->obj, sel, field, str))
+  if (chk_sputobjfield(d->obj, sel, field, str)) {
+    menu_lock(FALSE);
     return;
+  }
+
+  menu_lock(FALSE);
 
   d->select = sel;
   d->update(d, FALSE);
@@ -3750,19 +3785,8 @@ axiswin_ev_key_down(GtkWidget *w, GdkEvent *event, gpointer user_data)
 }
 
 void
-CmAxisWindow(GtkToggleAction *action, gpointer client_data)
+AxisWinState(struct SubWin *d, int state)
 {
-  struct SubWin *d;
-  int state;
-
-  d = &(NgraphApp.AxisWin);
-
-  if (action) {
-    state = gtk_toggle_action_get_active(action);
-  } else {
-    state = TRUE;
-  }
-
   if (d->Win) {
     sub_window_set_visibility(d, state);
     return;
@@ -3772,7 +3796,7 @@ CmAxisWindow(GtkToggleAction *action, gpointer client_data)
     return;
   }
 
-  list_sub_window_create(d, "Axis Window", AXIS_WIN_COL_NUM, Alist, Axiswin_xpm, Axiswin48_xpm);
+  list_sub_window_create(d, "Axis Window", AXIS_WIN_COL_NUM, Alist, NGRAPH_AXISWIN_ICON_FILE, NGRAPH_AXISWIN_ICON48_FILE);
 
   d->data.data->update = AxisWinUpdate;
   d->data.data->setup_dialog = AxisDialog;
@@ -3788,6 +3812,11 @@ CmAxisWindow(GtkToggleAction *action, gpointer client_data)
   set_editable_cell_renderer_cb(d->data.data, AXIS_WIN_COL_MAX, Alist, G_CALLBACK(max_edited));
   set_editable_cell_renderer_cb(d->data.data, AXIS_WIN_COL_INC, Alist, G_CALLBACK(inc_edited));
 
+  set_cell_attribute_source(d, "style", AXIS_WIN_COL_NAME, AXIS_WIN_COL_MATH);
+  set_cell_attribute_source(d, "style", AXIS_WIN_COL_MIN, AXIS_WIN_COL_MATH);
+  set_cell_attribute_source(d, "style", AXIS_WIN_COL_MAX, AXIS_WIN_COL_MATH);
+  set_cell_attribute_source(d, "style", AXIS_WIN_COL_INC, AXIS_WIN_COL_MATH);
+
   set_combo_cell_renderer_cb(d->data.data, AXIS_WIN_COL_TYPE, Alist, G_CALLBACK(start_editing_type), NULL);
 
   list_store_set_align(GTK_WIDGET(d->data.data->text), AXIS_WIN_COL_MIN, 1.0);
@@ -3796,5 +3825,5 @@ CmAxisWindow(GtkToggleAction *action, gpointer client_data)
 
   gtk_tree_view_set_enable_search(GTK_TREE_VIEW(d->data.data->text), TRUE);
   gtk_tree_view_set_search_column(GTK_TREE_VIEW(d->data.data->text), AXIS_WIN_COL_NAME);
-  gtk_tree_view_set_tooltip_column(GTK_TREE_VIEW(d->data.data->text), AXIS_WIN_COL_NAME);
+  tree_view_set_tooltip_column(GTK_TREE_VIEW(d->data.data->text), AXIS_WIN_COL_NAME);
 }
