@@ -38,11 +38,11 @@
 #include "ioutil.h"
 #include "shell.h"
 #include "nstring.h"
-#include "ofile.h"
+#include "odata.h"
 #include "odraw.h"
 #include "nconfig.h"
 
-#include "main.h"
+#include "init.h"
 #include "gtk_widget.h"
 #include "x11gui.h"
 #include "x11graph.h"
@@ -51,6 +51,7 @@
 #include "x11menu.h"
 #include "x11commn.h"
 #include "x11info.h"
+#include "x11file.h"
 
 #define COMMENT_BUF_SIZE 1024
 
@@ -349,7 +350,7 @@ AxisDel2(int id)
     }
   }
 
-  obj = getobject("file");
+  obj = getobject("data");
   if (obj == NULL) {
     return;
   }
@@ -434,7 +435,7 @@ axis_move_each_obj(char *axis_str, int i, struct objlist *obj, int id1, int id2)
   int spc, aid;
   char *axis, *axis2;
   struct narray iarray;
-  int anum, len;
+  int anum;
 
   if (getobj(obj, axis_str, i, 0, NULL, &axis) < 0 || axis == NULL)
     return;
@@ -454,10 +455,8 @@ axis_move_each_obj(char *axis_str, int i, struct objlist *obj, int id1, int id2)
       if (aid >= id2)
 	aid++;
     }
-    len = strlen(chkobjectname(aobj)) + 10;
-    axis2 = (char *) g_malloc(len);
+    axis2 = g_strdup_printf("%s:%d", chkobjectname(aobj), aid);
     if (axis2) {
-      snprintf(axis2, len, "%s:%d", chkobjectname(aobj), aid);
       putobj(obj, axis_str, i, axis2);
     }
   }
@@ -470,7 +469,7 @@ AxisMove(int id1, int id2)
   struct objlist *obj;
   int i;
 
-  if ((obj = getobject("file")) == NULL)
+  if ((obj = getobject("data")) == NULL)
     return;
 
   for (i = 0; i <= chkobjlastinst(obj); i++) {
@@ -666,20 +665,21 @@ AxisNameToGroup(void)		/* this function may exist for compatibility with older v
   arraydel(&iarray);
 }
 
-void
-FitDel(struct objlist *obj, int id)
+static void
+field_obj_del(struct objlist *obj, int id, const char *field)
 {
   char *fit;
   struct objlist *fitobj;
-  int fitid, idnum;
+  int fitid, idnum, i;
   struct narray iarray;
 
-  if ((getobj(obj, "fit", id, 0, NULL, &fit) >= 0) && (fit != NULL)) {
+  if ((getobj(obj, field, id, 0, NULL, &fit) >= 0) && (fit != NULL)) {
     arrayinit(&iarray, sizeof(int));
     if (getobjilist(fit, &fitobj, &iarray, FALSE, NULL) == 0) {
       idnum = arraynum(&iarray);
-      if (idnum >= 1) {
-	fitid = arraylast_int(&iarray);
+      arraysort_int(&iarray);
+      for (i = idnum - 1; i >= 0; i--) {
+	fitid = arraynget_int(&iarray, i);
 	delobj(fitobj, fitid);
       }
     }
@@ -687,6 +687,18 @@ FitDel(struct objlist *obj, int id)
   }
 }
 
+void
+FitDel(struct objlist *obj, int id)
+{
+  field_obj_del(obj, id, "fit");
+}
+
+void
+ArrayDel(struct objlist *obj, int id)
+{
+  field_obj_del(obj, id, "array");
+}
+
 void
 FitCopy(struct objlist *obj, int did, int sid)
 {
@@ -745,7 +757,7 @@ FitClear(void)
 
   if (Menulock || Globallock)
     return;
-  if ((obj = chkobject("file")) == NULL)
+  if ((obj = chkobject("data")) == NULL)
     return;
   if ((fitobj = chkobject("fit")) == NULL)
     return;
@@ -769,89 +781,270 @@ FitClear(void)
   }
 }
 
+static void
+del_darray(struct objlist *data_obj)
+{
+  char *array;
+  int i, j, n, id, last;
+  struct array_prm ary;
+  struct narray *id_array;
+  struct objlist *darray_obj;
+
+  darray_obj = chkobject("darray");
+  if (darray_obj == NULL) {
+    return;
+  }
+
+  last = chkobjlastinst(data_obj);
+  if (last < 0) {
+    return;
+  }
+
+  id_array = arraynew(sizeof(int));
+  if (id_array == NULL) {
+    return;
+  }
+
+  for (i = 0; i <= last; i++) {
+    getobj(data_obj, "array", i, 0, NULL, &array);
+    if (array == NULL) {
+      continue;
+    }
+    open_array(array, &ary);
+    for (j = 0; j < ary.col_num; j++) {
+      arrayadd(id_array, &ary.id[j]);
+    }
+  }
+
+  arraysort_int(id_array);
+  arrayuniq_int(id_array);
+
+  n = arraynum(id_array);
+  for (i = 0; i < n; i++) {
+    id = arraynget_int(id_array, n - 1 - i);
+    delobj(darray_obj, id);
+  }
+  arrayfree(id_array);
+}
+
 void
 DeleteDrawable(void)
 {
   struct objlist *fileobj, *drawobj;
   int i;
 
-  if ((fileobj = chkobject("file")) != NULL) {
-    for (i = 0; i <= chkobjlastinst(fileobj); i++)
+  fileobj = chkobject("data");
+  if (fileobj) {
+    for (i = 0; i <= chkobjlastinst(fileobj); i++) {
       FitDel(fileobj, i);
+    }
+    del_darray(fileobj);
   }
-  if ((drawobj = chkobject("draw")) != NULL)
+
+  drawobj = chkobject("draw");
+  if (drawobj) {
     delchildobj(drawobj);
+  }
+}
+
+static void
+store_file(struct objlist *ocur, int hFile, int i)
+{
+  char *s, *fname, *fname2;
+  int j;
+  N_VALUE *inst;
+
+  getobj(ocur, "file", i, 0, NULL, &fname);
+  if (fname == NULL) {
+    return;
+  }
+
+  for (j = i - 1; j >= 0; j--) {
+    getobj(ocur, "file", j, 0, NULL, &fname2);
+    if ((fname2 != NULL) && (strcmp0(fname, fname2) == 0)) {
+      break;
+    }
+  }
+  inst = chkobjinst(ocur, i);
+  if (j == -1) {
+    while (_exeobj(ocur, "store_data", inst, 0, NULL) == 0) {
+      _getobj(ocur, "store_data", inst, &s);
+      nwrite(hFile, s, strlen(s));
+      nwrite(hFile, "\n", 1);
+    }
+  } else {
+    while (_exeobj(ocur, "store_dummy", inst, 0, NULL) == 0) {
+      _getobj(ocur, "store_dummy", inst, &s);
+      nwrite(hFile, s, strlen(s));
+      nwrite(hFile, "\n", 1);
+    }
+  }
+}
+
+static void
+save_array(struct objlist *ocur, int hFile, int i, GString *str)
+{
+  char *s, *array, *array2, iarray_str[] = "iarray:!:push ${darray:!:oid}\n\n";
+  int j, k, l, n, id;
+  struct array_prm ary, ary2;
+  struct narray *id_array;
+
+  getobj(ocur, "array", i, 0, NULL, &array);
+  if (array == NULL) {
+    return;
+  }
+
+  id_array = arraynew(sizeof(int));
+  for (j = 0; j < i; j++) {
+    getobj(ocur, "array", j, 0, NULL, &array2);
+    if (array2 == NULL) {
+      continue;
+    }
+    open_array(array2, &ary2);
+    for (k = 0; k < ary2.col_num; k++) {
+      n = arraynum(id_array);
+      for (l = 0; l < n; l++) {
+	id = arraynget_int(id_array, l);
+	if (id == ary2.id[k]) {
+	  break;
+	}
+      }
+      if (l == n) {
+	arrayadd(id_array, &ary2.id[k]);
+      }
+    }
+  }
+
+  open_array(array, &ary);
+  for (k = 0; k < ary.col_num; k++) {
+    n = arraynum(id_array);
+    for (l = 0; l < n; l++) {
+      id = arraynget_int(id_array, l);
+      if (id == ary2.id[k]) {
+	break;
+      }
+    }
+    if (l == n) {
+      arrayadd(id_array, &ary.id[k]);
+      if (getobj(ary.obj, "save", ary.id[k], 0, NULL, &s) != -1) {
+	nwrite(hFile, s, strlen(s));
+	nwrite(hFile, "\n", 1);
+	nwrite(hFile, iarray_str, sizeof(iarray_str) - 1);
+      }
+    }
+    g_string_append_printf(str, "%s^${iarray:!:get:%d}", (k == 0) ? "darray:\"" : ",", l);
+  }
+  arrayfree(id_array);
+}
+
+static void
+save_merge(struct objlist *ocur, int hFile, int storemerge, int i)
+{
+  char *s;
+
+  getobj(ocur, "save", i, 0, NULL, &s);
+  nwrite(hFile, s, strlen(s));
+  nwrite(hFile, "\n", 1);
+  if (storemerge) {
+    store_file(ocur, hFile, i);
+  }
+}
+
+static void
+save_data(struct objlist *ocur, int hFile, int storedata, int i, int *array_data)
+{
+  char *s;
+  int source, argc;
+  char *argv2[3], **argv;
+  struct narray *array;
+  GString *str;
+
+  str = NULL;
+  argc = 0;
+  argv = NULL;
+  array = NULL;
+  getobj(ocur, "source", i, 0, NULL, &source);
+  switch (source) {
+  case DATA_SOURCE_FILE:
+    break;
+  case DATA_SOURCE_ARRAY:
+    array = arraynew(sizeof(char *));
+    if (array == NULL) {
+      error(NULL, ERRHEAP);
+      return;
+    }
+    s = "array";
+    arrayadd(array, &s);
+    argv2[0] = (char *) array;
+    argv2[1] = NULL;
+
+    argv = argv2;
+    argc = 1;
+
+    str = g_string_new("\tdata::array=");
+    if (str == NULL) {
+      error(NULL, ERRHEAP);
+      return;
+    }
+    if (! *array_data) {
+      char iarray_str[] = "new iarray\n\n";
+      *array_data = TRUE;
+      nwrite(hFile, iarray_str, sizeof(iarray_str) - 1);
+    }
+    save_array(ocur, hFile, i, str);
+    break;
+  case DATA_SOURCE_RANGE:
+    break;
+  }
+
+  getobj(ocur, "save", i, argc, argv, &s);
+  nwrite(hFile, s, strlen(s));
+  if (storedata) {
+    store_file(ocur, hFile, i);
+  }
+
+  if (array) {
+    arrayfree(array);
+  }
+
+  if (str) {
+    nwrite(hFile, str->str, str->len);
+    nwrite(hFile, "\"\n", 2);
+    g_string_free(str, TRUE);
+  }
+  nwrite(hFile, "\n", 1);
 }
 
 static void
 SaveParent(int hFile, struct objlist *parent, int storedata,
 	   int storemerge)
 {
-  struct objlist *ocur;
-  int i, j, instnum;
+  struct objlist *ocur, *odata, *omerge;
+  int i, instnum, array_data;
   char *s;
-  N_VALUE *inst;
-  char *fname, *fname2;
 
   ocur = chkobjroot();
-  while (ocur != NULL) {
+  odata = chkobject("data");
+  omerge = chkobject("merge");
+  array_data = FALSE;
+  while (ocur) {
     if (chkobjparent(ocur) == parent) {
       if ((instnum = chkobjlastinst(ocur)) != -1) {
 	for (i = 0; i <= instnum; i++) {
-	  getobj(ocur, "save", i, 0, NULL, &s);
-	  nwrite(hFile, s, strlen(s));
-	  nwrite(hFile, "\n", 1);
-	  if (storedata && (ocur == chkobject("file"))) {
-	    getobj(ocur, "file", i, 0, NULL, &fname);
-	    if (fname != NULL) {
-	      for (j = i - 1; j >= 0; j--) {
-		getobj(ocur, "file", j, 0, NULL, &fname2);
-		if ((fname2 != NULL)
-		    && (strcmp0(fname, fname2) == 0))
-		  break;
-	      }
-	      inst = chkobjinst(ocur, i);
-	      if (j == -1) {
-		while (_exeobj(ocur, "store_data", inst, 0, NULL) == 0) {
-		  _getobj(ocur, "store_data", inst, &s);
-		  nwrite(hFile, s, strlen(s));
-		  nwrite(hFile, "\n", 1);
-		}
-	      } else {
-		while (_exeobj(ocur, "store_dummy", inst, 0, NULL) == 0) {
-		  _getobj(ocur, "store_dummy", inst, &s);
-		  nwrite(hFile, s, strlen(s));
-		  nwrite(hFile, "\n", 1);
-		}
-	      }
-	    }
-	  }
-	  if (storemerge && (ocur == chkobject("merge"))) {
-	    getobj(ocur, "file", i, 0, NULL, &fname);
-	    if (fname != NULL) {
-	      for (j = i - 1; j >= 0; j--) {
-		getobj(ocur, "file", j, 0, NULL, &fname2);
-		if ((fname2 != NULL)
-		    && (strcmp0(fname, fname2) == 0))
-		  break;
-	      }
-	      inst = chkobjinst(ocur, i);
-	      if (j == -1) {
-		while (_exeobj(ocur, "store_data", inst, 0, NULL) == 0) {
-		  _getobj(ocur, "store_data", inst, &s);
-		  nwrite(hFile, s, strlen(s));
-		  nwrite(hFile, "\n", 1);
-		}
-	      } else {
-		while (_exeobj(ocur, "store_dummy", inst, 0, NULL) == 0) {
-		  _getobj(ocur, "store_dummy", inst, &s);
-		  nwrite(hFile, s, strlen(s));
-		  nwrite(hFile, "\n", 1);
-		}
-	      }
-	    }
+	  if (ocur == odata) {
+	    save_data(ocur, hFile, storedata, i, &array_data);
+	  } else if (ocur == omerge) {
+	    save_merge(ocur, hFile, storemerge, i);
+	  } else {
+	    getobj(ocur, "save", i, 0, NULL, &s);
+	    nwrite(hFile, s, strlen(s));
+	    nwrite(hFile, "\n", 1);
 	  }
 	}
+	if (ocur == odata && array_data) {
+	  char iarray_str[] = "del iarray:!\n\n";
+	  nwrite(hFile, iarray_str, sizeof(iarray_str) -1);
+	}
       }
       SaveParent(hFile, ocur, storedata, storemerge);
     }
@@ -927,7 +1120,7 @@ get_save_opt(int *sdata, int *smerge, int *path)
   *sdata = FALSE;
   *smerge = FALSE;
 
-  fobj = chkobject("file");
+  fobj = chkobject("data");
   mobj = chkobject("merge");
 
   fnum = (fobj) ? chkobjlastinst(fobj) : -1;
@@ -960,16 +1153,11 @@ GraphSave(int overwrite)
   int path;
   int sdata, smerge;
   int ret;
-  char *ext;
   char *initfil;
   char *file, *prev_wd, *current_wd;
 
   if (NgraphApp.FileName != NULL) {
     initfil = NgraphApp.FileName;
-    if ((ext = getextention(initfil)) != NULL) {
-      if ((strcmp0(ext, "PRM") == 0) || (strcmp0(ext, "prm") == 0))
-	strcpy(ext, "ngp");
-    }
   } else {
     initfil = NULL;
     overwrite = FALSE;
@@ -1101,9 +1289,8 @@ ToBasename(void)
 }
 
 
-void
-LoadNgpFile(char *file, int loadpath, int expand, char *exdir,
-	    int console, char *option)
+int
+LoadNgpFile(char *file, int console, char *option)
 {
   struct objlist *sys;
   char *expanddir;
@@ -1119,22 +1306,29 @@ LoadNgpFile(char *file, int loadpath, int expand, char *exdir,
   N_VALUE *inst;
   struct objlist *robj;
   int idn;
+  int loadpath, expand;
 
+  LoadDialog(&DlgLoad);
+  if (DialogExecute(TopLevel, &DlgLoad) != IDOK) {
+    return 1;
+  }
   changefilename(file);
 
   if (naccess(file, R_OK)) {
     ErrorMessage();
-    return;
+    return 1;
   }
 
   sys = chkobject("system");
-  if (sys == NULL)
-    return;
-
-  expanddir = g_strdup(exdir);
+  if (sys == NULL) {
+    return 1;
+  }
 
+  loadpath = DlgLoad.loadpath;
+  expand = DlgLoad.expand;
+  expanddir = g_strdup(DlgLoad.exdir);
   if (expanddir == NULL)
-    return;
+    return 1;
 
   putobj(sys, "expand_dir", 0, expanddir);
   putobj(sys, "expand_file", 0, &expand);
@@ -1144,11 +1338,11 @@ LoadNgpFile(char *file, int loadpath, int expand, char *exdir,
 
   obj = chkobject("shell");
   if (obj == NULL)
-    return;
+    return 1;
 
   newid = newobj(obj);
   if (newid < 0)
-    return;
+    return 1;
 
   inst = chkobjinst(obj, newid);
   arrayinit(&sarray, sizeof(char *));
@@ -1156,7 +1350,7 @@ LoadNgpFile(char *file, int loadpath, int expand, char *exdir,
     if (arrayadd(&sarray, &s) == NULL) {
       g_free(s);
       arraydel2(&sarray);
-      return;
+      return 1;
     }
   }
 
@@ -1164,13 +1358,13 @@ LoadNgpFile(char *file, int loadpath, int expand, char *exdir,
 
   if (name == NULL) {
     arraydel2(&sarray);
-    return;
+    return 1;
   }
 
   if (arrayadd(&sarray, &name) == NULL) {
     g_free(name);
     arraydel2(&sarray);
-    return;
+    return 1;
   }
 
   DeleteDrawable();
@@ -1242,47 +1436,8 @@ LoadNgpFile(char *file, int loadpath, int expand, char *exdir,
   GetPageSettingsFromGRA();
   UpdateAll();
   delobj(obj, newid);
-}
 
-void
-LoadPrmFile(char *file)
-{
-  struct objlist *obj;
-  char *name;
-  int id;
-  char mes[256];
-
-  obj = chkobject("prm");
-  if (obj == NULL)
-    return;
-
-  id = newobj(obj);
-  if (id < 0)
-    return;
-
-  name = g_strdup(file);
-  if (name == NULL) {
-    delobj(obj, id);
-    return;
-  }
-  changefilename(name);
-  putobj(obj, "file", id, name);
-  PrmDialog(&DlgPrm, obj, id);
-  if (DialogExecute(TopLevel, &DlgPrm) == IDOK) {
-    snprintf(mes, sizeof(mes), _("Loading `%.128s'."), name);
-    SetStatusBar(mes);
-    DeleteDrawable();
-    exeobj(obj, "load", id, 0, NULL);
-    GetPageSettingsFromGRA();
-    UpdateAll();
-    ResetStatusBar();
-    SetFileName(file);
-    set_graph_modified();
-    InfoWinClear();
-  }
-  delobj(obj, id);
-
-  set_axis_undo_button_sensitivity(FALSE);
+  return 0;
 }
 
 void
@@ -1304,7 +1459,7 @@ FileAutoScale(void)
   int refother;
   GString *str;
 
-  if ((fobj = chkobject("file")) == NULL)
+  if ((fobj = chkobject("data")) == NULL)
     return;
 
   lastinst = chkobjlastinst(fobj);
@@ -1425,7 +1580,7 @@ add_hist(const char *file, char *mime)
   uri = g_filename_to_uri(full_name, NULL, NULL);
   g_free(full_name);
 
-  gtk_recent_manager_add_full(Menulocal.ngpfilelist, uri, &recent_data);
+  gtk_recent_manager_add_full(NgraphApp.recent_manager, uri, &recent_data);
   g_free(uri);
 }
 
@@ -1486,21 +1641,51 @@ free_console(int allocnow)
   ninterrupt = mgtkinterrupt;
 }
 
-char *
-FileCB(struct objlist *obj, int id)
+static char *
+get_plot_cb_str(struct objlist *obj, int id, int source)
 {
-  char *valstr, *file, *s;
+  char *valstr, *s;
+  const char *str;
 
-  getobj(obj, "file", id, 0, NULL, &file);
-  valstr = getbasename(file);
-  s = g_strdup_printf("%s", (valstr) ? valstr : "....................");
-  if (valstr != NULL) {
-    g_free(valstr);
+  str = get_plot_info_str(obj, id, source);
+  if (str == NULL) {
+    return g_strdup("....................");
+  }
+
+  if (source == DATA_SOURCE_FILE) {
+    valstr = getbasename(str);
+    s = g_strdup_printf("%s", (valstr) ? valstr : "....................");
+    if (valstr != NULL) {
+      g_free(valstr);
+    }
+  } else {
+    s = g_strdup(str);
   }
 
   return s;
 }
 
+char *
+FileCB(struct objlist *obj, int id)
+{
+  int source;
+
+  getobj(obj, "source", id, 0, NULL, &source);
+  return get_plot_cb_str(obj, id, source);
+}
+
+char *
+PlotFileCB(struct objlist *obj, int id)
+{
+  int source;
+
+  getobj(obj, "source", id, 0, NULL, &source);
+  if (source != DATA_SOURCE_FILE) {
+    return NULL;
+  }
+  return get_plot_cb_str(obj, id, source);
+}
+
 int
 SetFileHidden(void)
 {
@@ -1509,7 +1694,7 @@ SetFileHidden(void)
   struct narray farray, ifarray;
   int i, a, r, num, inum, *array;
 
-  fobj = chkobject("file");
+  fobj = chkobject("data");
   if (fobj == NULL) {
     return 1;
   }
@@ -1639,7 +1824,7 @@ cb_del(GtkWidget *w, GdkEvent *event, gpointer user_data)
 static void
 stop_btn_clicked(GtkButton *button, gpointer user_data)
 {
-  NgraphApp.Interrupt = TRUE;
+  set_interrupt();
 }
 
 void
@@ -1653,6 +1838,8 @@ ProgressDialogCreate(char *title)
   if (ProgressDialog)
     gtk_widget_destroy(ProgressDialog);
 
+  reset_interrupt();
+
   SaveCursor = NGetCursor();
   NSetCursor(GDK_WATCH);
 
@@ -1692,7 +1879,8 @@ ProgressDialogCreate(char *title)
 #else
   hbox = gtk_hbox_new(FALSE, 4);
 #endif
-  btn = gtk_button_new_from_stock(GTK_STOCK_STOP);
+  btn = gtk_button_new_with_mnemonic(_("_Stop"));
+  set_button_icon(btn, "process-stop");
   g_signal_connect(btn, "clicked", G_CALLBACK(stop_btn_clicked), NULL);
 
   gtk_box_pack_end(GTK_BOX(hbox), btn, FALSE, FALSE, 4);
