@@ -61,6 +61,8 @@ char *FwNumStyle[] =
 int FwNumStyleNum = sizeof(FwNumStyle) / sizeof(*FwNumStyle);
 
 struct FileDialog DlgFile;
+struct FileDialog DlgRange;
+struct FileDialog DlgArray;
 struct FileDialog DlgFileDef;
 struct EvalDialog DlgEval;
 struct MathDialog DlgMath;
@@ -84,7 +86,6 @@ struct LegendGaussDialog DlgLegendGauss;
 struct PageDialog DlgPage;
 struct SwitchDialog DlgSwitch;
 struct DirectoryDialog DlgDirectory;
-struct PrmDialog DlgPrm;
 struct LoadDialog DlgLoad;
 struct SaveDialog DlgSave;
 struct DriverDialog DlgDriver;
@@ -118,10 +119,22 @@ initdialog(void)
 {
   DlgFile.widget = NULL;
   DlgFile.focus = NULL;
-  DlgFile.resource = N_("data");
+  DlgFile.resource = N_("file");
   DlgFile.mark.widget = NULL;
   DlgFile.mark.focus = NULL;
   DlgFile.mark.resource = N_("mark selection");
+  DlgRange.widget = NULL;
+  DlgRange.focus = NULL;
+  DlgRange.resource = N_("function");
+  DlgRange.mark.widget = NULL;
+  DlgRange.mark.focus = NULL;
+  DlgRange.mark.resource = NULL;
+  DlgArray.widget = NULL;
+  DlgArray.focus = NULL;
+  DlgArray.resource = N_("array");
+  DlgArray.mark.widget = NULL;
+  DlgArray.mark.focus = NULL;
+  DlgArray.mark.resource = NULL;
   DlgFileDef.widget = NULL;
   DlgFileDef.focus = NULL;
   DlgFileDef.resource = N_("data default");
@@ -202,10 +215,8 @@ initdialog(void)
   DlgDirectory.resource = N_("directory");
   DlgLoad.widget = NULL;
   DlgLoad.focus = NULL;
+  DlgLoad.exdir = NULL;
   DlgLoad.resource = N_("load");
-  DlgPrm.widget = NULL;
-  DlgPrm.focus = NULL;
-  DlgPrm.resource = N_("loadprm");
   DlgSave.widget = NULL;
   DlgSave.focus = NULL;
   DlgSave.resource = N_("save");
@@ -340,7 +351,8 @@ SelectDialogSetup(GtkWidget *wi, void *data, int makewidget)
 #else
     hbox = gtk_hbox_new(FALSE, 4);
 #endif
-    w = gtk_button_new_from_stock(GTK_STOCK_SELECT_ALL);
+    w = gtk_button_new_with_mnemonic(_("Select _All"));
+    set_button_icon(w, "edit-select-all");
     g_signal_connect(w, "clicked", G_CALLBACK(list_store_select_all_cb), d->list);
     gtk_box_pack_start(GTK_BOX(hbox), w, FALSE, FALSE, 4);
     gtk_box_pack_start(GTK_BOX(d->vbox), hbox, FALSE, FALSE, 4);
