@@ -69,11 +69,10 @@ int putobj_stroke_color(GtkWidget *w, struct objlist *obj, int id);
 int chk_sputobjfield(struct objlist *obj, int id, char *field, char *str);
 const char *get_style_string(struct objlist *obj, int id, char *field);
 
-#define DIALOG_PROTOTYPE GtkWidget *parent, *widget, *focus;\
+#define DIALOG_PROTOTYPE GtkWidget *parent, *widget, *focus;	\
   GtkBox *vbox;\
   int ret, show_cancel;\
-  char *resource;\
-  const char *ok_button;\
+  char *resource, *ok_button;\
   void (*SetupWindow) (GtkWidget *w, void *data, int makewidget);\
   void (*CloseWindow) (GtkWidget *w, void *data);\
 
@@ -122,11 +121,11 @@ struct FileDialog
   /****** local member *******/
   GtkWidget *file, *load_settings, *fit, *xcol, *xaxis, *ycol, *yaxis,
     *type, *mark_btn, *curve, *col1, *col2,
-    *clip, *style, *size, *miter, *join,
+    *clip, *style, *size, *miter, *join, *min, *max, *div,
     *comment_box, *file_box, *fit_table, *width, *apply_all, *comment_view, *comment_table;
   GtkNotebook *tab;
   struct objlist *Obj;
-  int Id;
+  int Id, source;
   struct MarkDialog mark;
   int R, G, B, R2, G2, B2, alpha, multi_open, fit_row, initialized;
   struct FileMath math;
@@ -266,7 +265,7 @@ struct AxisNumbering
 {
   GtkWidget *num, *begin, *ster, *numnum, *head, *fraction, *add_plus, *tail,
     *date_format, *align, *direction, *shiftp, *shiftn,
-    *log_power, *no_zero, *norm, *step;
+    *log_power, *no_zero, *norm, *step, *math;
   int tab_id;
 };
 
@@ -415,16 +414,6 @@ struct LoadDialog
 };
 void LoadDialog(struct LoadDialog *data);
 
-struct PrmDialog
-{
-  DIALOG_PROTOTYPE;
-  /****** local member *******/
-  GtkWidget *ignore_path;
-  struct objlist *Obj;
-  int Id;
-};
-void PrmDialog(struct PrmDialog *data, struct objlist *obj, int id);
-
 struct SaveDialog
 {
   DIALOG_PROTOTYPE;
@@ -603,6 +592,8 @@ void OutputImageDialog(struct OutputImageDialog *data, int type);
 
 
 extern struct FileDialog DlgFile;
+extern struct FileDialog DlgRange;
+extern struct FileDialog DlgArray;
 extern struct FileDialog DlgFileDef;
 extern struct EvalDialog DlgEval;
 extern struct MathDialog DlgMath;
@@ -634,7 +625,6 @@ extern struct PageDialog DlgPage;
 extern struct SwitchDialog DlgSwitch;
 extern struct DirectoryDialog DlgDirectory;
 extern struct LoadDialog DlgLoad;
-extern struct PrmDialog DlgPrm;
 extern struct SaveDialog DlgSave;
 extern struct DriverDialog DlgDriver;
 extern struct PrintDialog DlgPrinter;
