@@ -100,7 +100,7 @@ dialog_key_down_cb(GtkWidget *w, GdkEvent *event, gpointer user_data)
       gtk_dialog_response(GTK_DIALOG(w), GTK_RESPONSE_CANCEL);
       return TRUE;
     }
-    return FALSE;
+    break;
   }
   return FALSE;
 }
@@ -131,7 +131,7 @@ ndialog_run(GtkWidget *dlg)
 int
 DialogExecute(GtkWidget *parent, void *dialog)
 {
-  GtkWidget *dlg, *win_ptr;
+  GtkWidget *dlg, *win_ptr, *btn;
   struct DialogType *data;
   gint res_id, lockstate;
 
@@ -152,12 +152,16 @@ DialogExecute(GtkWidget *parent, void *dialog)
   }
 
   if (data->widget == NULL) {
-    dlg = gtk_dialog_new();
+    dlg = gtk_dialog_new_with_buttons(_(data->resource),
+				      GTK_WINDOW(parent),
+#if GTK_CHECK_VERSION(3, 12, 0) && USE_HEADER_BAR
+				      GTK_DIALOG_USE_HEADER_BAR |
+#endif
+				      GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
+				      _("_Cancel"), GTK_RESPONSE_CANCEL,
+				      NULL);
 
-    gtk_window_set_transient_for(GTK_WINDOW(dlg), GTK_WINDOW(parent));
-    gtk_window_set_modal(GTK_WINDOW(dlg), TRUE);
     gtk_window_set_resizable(GTK_WINDOW(dlg), TRUE);
-    gtk_window_set_destroy_with_parent(GTK_WINDOW(dlg), TRUE);
 
     g_signal_connect(dlg, "delete-event", G_CALLBACK(dialog_delete_cb), data);
     g_signal_connect(dlg, "destroy", G_CALLBACK(dialog_destroyed_cb), data);
@@ -167,18 +171,19 @@ DialogExecute(GtkWidget *parent, void *dialog)
     data->widget = dlg;
     data->vbox = GTK_BOX(gtk_dialog_get_content_area(GTK_DIALOG(dlg)));
     data->show_cancel = TRUE;
-    data->ok_button = GTK_STOCK_OK;
+    data->ok_button = _("_OK");
 
     gtk_window_set_title(GTK_WINDOW(dlg), _(data->resource));
 
     data->SetupWindow(dlg, data, TRUE);
 
-    if (data->show_cancel) {
-      gtk_dialog_add_button(GTK_DIALOG(dlg), GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL);
-    }
-
     gtk_dialog_add_button(GTK_DIALOG(dlg), data->ok_button, GTK_RESPONSE_OK);
 
+    if (! data->show_cancel) {
+      btn = gtk_dialog_get_widget_for_response(GTK_DIALOG(dlg), GTK_RESPONSE_CANCEL);
+      gtk_widget_hide(btn);
+    }
+
     gtk_dialog_set_default_response(GTK_DIALOG(dlg), GTK_RESPONSE_OK);
   } else {
     dlg = data->widget;
@@ -274,6 +279,9 @@ message_box(GtkWidget * parent, const char *message, const char *title, int mode
 
   switch (mode) {
   case RESPONS_YESNOCANCEL:
+    dlg_button = GTK_BUTTONS_CANCEL;
+    dlg_type = GTK_MESSAGE_QUESTION;
+    break;
   case RESPONS_YESNO:
     dlg_button = GTK_BUTTONS_YES_NO;
     dlg_type = GTK_MESSAGE_QUESTION;
@@ -298,7 +306,9 @@ message_box(GtkWidget * parent, const char *message, const char *title, int mode
 
   switch (mode) {
   case RESPONS_YESNOCANCEL:
-  case RESPONS_YESNO:
+    gtk_dialog_add_button(GTK_DIALOG(dlg), _("_No"), GTK_RESPONSE_NO);
+    gtk_dialog_add_button(GTK_DIALOG(dlg), _("_Yes"), GTK_RESPONSE_YES);
+  case RESPONS_YESNO:		/* fall-through */
     gtk_dialog_set_default_response(GTK_DIALOG(dlg), GTK_RESPONSE_YES);
     break;
   }
@@ -306,12 +316,6 @@ message_box(GtkWidget * parent, const char *message, const char *title, int mode
   gtk_window_set_title(GTK_WINDOW(dlg), title);
   gtk_window_set_resizable(GTK_WINDOW(dlg), FALSE);
 
-  if (mode == RESPONS_YESNOCANCEL) {
-    gtk_dialog_add_button(GTK_DIALOG(dlg),
-			  GTK_STOCK_CANCEL,
-			  GTK_RESPONSE_CANCEL);
-  }
-
   gtk_widget_show_all(dlg);
   res_id = ndialog_run(dlg);
 
@@ -354,9 +358,12 @@ DialogInput(GtkWidget * parent, const char *title, const char *mes, const char *
 
   dlg = gtk_dialog_new_with_buttons(title,
 				    GTK_WINDOW(parent),
+#if GTK_CHECK_VERSION(3, 12, 0) && USE_HEADER_BAR
+				    GTK_DIALOG_USE_HEADER_BAR |
+#endif
 				    GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
-				    GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-				    GTK_STOCK_OK, GTK_RESPONSE_OK,
+				    _("_Cancel"), GTK_RESPONSE_CANCEL,
+				    _("_OK"), GTK_RESPONSE_OK,
 				    NULL);
   gtk_dialog_set_default_response(GTK_DIALOG(dlg), GTK_RESPONSE_OK);
   gtk_window_set_resizable(GTK_WINDOW(dlg), FALSE);
@@ -414,9 +421,12 @@ DialogRadio(GtkWidget *parent, const char *title, const char *caption, struct na
 
   dlg = gtk_dialog_new_with_buttons(title,
 				    GTK_WINDOW(parent),
+#if GTK_CHECK_VERSION(3, 12, 0) && USE_HEADER_BAR
+				    GTK_DIALOG_USE_HEADER_BAR |
+#endif
 				    GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
-				    GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-				    GTK_STOCK_OK, GTK_RESPONSE_OK,
+				    _("_Cancel"), GTK_RESPONSE_CANCEL,
+				    _("_OK"), GTK_RESPONSE_OK,
 				    NULL);
   gtk_dialog_set_default_response(GTK_DIALOG(dlg), GTK_RESPONSE_OK);
   gtk_window_set_resizable(GTK_WINDOW(dlg), FALSE);
@@ -529,9 +539,12 @@ DialogCombo(GtkWidget *parent, const char *title, const char *caption, struct na
 
   dlg = gtk_dialog_new_with_buttons(title,
 				    GTK_WINDOW(parent),
+#if GTK_CHECK_VERSION(3, 12, 0) && USE_HEADER_BAR
+				    GTK_DIALOG_USE_HEADER_BAR |
+#endif
 				    GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
-				    GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-				    GTK_STOCK_OK, GTK_RESPONSE_OK,
+				    _("_Cancel"), GTK_RESPONSE_CANCEL,
+				    _("_OK"), GTK_RESPONSE_OK,
 				    NULL);
   gtk_dialog_set_default_response(GTK_DIALOG(dlg), GTK_RESPONSE_OK);
   gtk_window_set_resizable(GTK_WINDOW(dlg), FALSE);
@@ -596,9 +609,12 @@ DialogComboEntry(GtkWidget *parent, const char *title, const char *caption, stru
 
   dlg = gtk_dialog_new_with_buttons(title,
 				    GTK_WINDOW(parent),
+#if GTK_CHECK_VERSION(3, 12, 0) && USE_HEADER_BAR
+				    GTK_DIALOG_USE_HEADER_BAR |
+#endif
 				    GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
-				    GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-				    GTK_STOCK_OK, GTK_RESPONSE_OK,
+				    _("_Cancel"), GTK_RESPONSE_CANCEL,
+				    _("_OK"), GTK_RESPONSE_OK,
 				    NULL);
   gtk_dialog_set_default_response(GTK_DIALOG(dlg), GTK_RESPONSE_OK);
   gtk_window_set_resizable(GTK_WINDOW(dlg), FALSE);
@@ -658,9 +674,12 @@ DialogSpinEntry(GtkWidget *parent, const char *title, const char *caption, doubl
 
   dlg = gtk_dialog_new_with_buttons(title,
 				    GTK_WINDOW(parent),
+#if GTK_CHECK_VERSION(3, 12, 0) && USE_HEADER_BAR
+				    GTK_DIALOG_USE_HEADER_BAR |
+#endif
 				    GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
-				    GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-				    GTK_STOCK_OK, GTK_RESPONSE_OK,
+				    _("_Cancel"), GTK_RESPONSE_CANCEL,
+				    _("_OK"), GTK_RESPONSE_OK,
 				    NULL);
   gtk_dialog_set_default_response(GTK_DIALOG(dlg), GTK_RESPONSE_OK);
   gtk_window_set_resizable(GTK_WINDOW(dlg), FALSE);
@@ -729,9 +748,12 @@ DialogCheck(GtkWidget *parent, const char *title, const char *caption, struct na
 
   dlg = gtk_dialog_new_with_buttons(title,
 				    GTK_WINDOW(parent),
+#if GTK_CHECK_VERSION(3, 12, 0) && USE_HEADER_BAR
+				    GTK_DIALOG_USE_HEADER_BAR |
+#endif
 				    GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
-				    GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-				    GTK_STOCK_OK, GTK_RESPONSE_OK,
+				    _("_Cancel"), GTK_RESPONSE_CANCEL,
+				    _("_OK"), GTK_RESPONSE_OK,
 				    NULL);
   gtk_dialog_set_default_response(GTK_DIALOG(dlg), GTK_RESPONSE_OK);
   gtk_window_set_resizable(GTK_WINDOW(dlg), FALSE);
@@ -966,9 +988,10 @@ FileSelectionDialog(GtkWidget *parent, int type, char *stock)
   dlg = gtk_file_chooser_dialog_new(data->title,
 				    GTK_WINDOW(data->parent),
 				    type,
-				    GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+				    _("_Cancel"), GTK_RESPONSE_CANCEL,
 				    stock, GTK_RESPONSE_ACCEPT,
 				    NULL);
+  gtk_file_chooser_set_local_only(GTK_FILE_CHOOSER(dlg), TRUE);
   rc = gtk_check_button_new_with_mnemonic(_("_Change current directory"));
   gtk_box_pack_start(GTK_BOX(gtk_dialog_get_content_area(GTK_DIALOG(dlg))), rc, FALSE, FALSE, 5);
   data->chdir_cb = rc;
@@ -1067,7 +1090,7 @@ nGetOpenFileNameMulti(GtkWidget * parent,
   FileSelection.overwrite = FALSE;
   FileSelection.multi = TRUE;
   FileSelection.changedir = TRUE;
-  ret = FileSelectionDialog(parent, GTK_FILE_CHOOSER_ACTION_OPEN, GTK_STOCK_OPEN);
+  ret = FileSelectionDialog(parent, GTK_FILE_CHOOSER_ACTION_OPEN, _("_Open"));
   if (ret == IDOK) {
     *file = FileSelection.file;
     if (FileSelection.chdir && init_dir && nchdir(*init_dir)) {
@@ -1102,7 +1125,7 @@ nGetOpenFileName(GtkWidget *parent,
 			    (exist) ?
 			    GTK_FILE_CHOOSER_ACTION_OPEN :
 			    GTK_FILE_CHOOSER_ACTION_SAVE,
-			    GTK_STOCK_OPEN);
+			    _("_Open"));
   if (ret == IDOK) {
     *file = FileSelection.file[0];
     g_free(FileSelection.file);
@@ -1133,7 +1156,7 @@ nGetSaveFileName(GtkWidget * parent,
   FileSelection.overwrite = overwrite;
   FileSelection.multi = FALSE;
   FileSelection.changedir = TRUE;
-  ret = FileSelectionDialog(parent, GTK_FILE_CHOOSER_ACTION_SAVE, GTK_STOCK_SAVE);
+  ret = FileSelectionDialog(parent, GTK_FILE_CHOOSER_ACTION_SAVE, _("_Save"));
   if (ret == IDOK) {
     *file = FileSelection.file[0];
     g_free(FileSelection.file);
