@@ -74,6 +74,11 @@ enum MenuID {
   MenuIdEditOrderBottom,
 };
 
+enum {
+  RECENT_TYPE_GRAPH,
+  RECENT_TYPE_DATA,
+};
+
 enum DrawLockVal {DrawLockNone, DrawLockDraw, DrawLockExpose};
 
 enum PointerType {
@@ -125,6 +130,9 @@ enum pop_up_menu_item_type {
   POP_UP_MENU_ITEM_TYPE_CHECK,
   POP_UP_MENU_ITEM_TYPE_MENU,
   POP_UP_MENU_ITEM_TYPE_SEPARATOR,
+  POP_UP_MENU_ITEM_TYPE_RECENT_GRAPH,
+  POP_UP_MENU_ITEM_TYPE_RECENT_DATA,
+  POP_UP_MENU_ITEM_TYPE_END,
 };
 
 #define VIEWER_POPUP_ITEM_NUM 14
@@ -147,6 +155,12 @@ struct Viewer
   double vscroll, hscroll, Zoom;
 };
 
+enum subwin_state {
+  SUBWIN_STATE_SHOW,
+  SUBWIN_STATE_HIDE,
+  SUBWIN_STATE_TOGGLE,
+};
+
 enum SubWinType {
   TypeFileWin,
   TypeAxisWin,
@@ -168,7 +182,6 @@ struct obj_list_data
   void (* setup_dialog)(struct obj_list_data *data, int id, int user_data);
   void *dialog;
   gboolean (* ev_key) (GtkWidget *, GdkEvent *, gpointer);
-  gboolean (* ev_button) (GtkWidget *, GdkEventButton *, gpointer);
   struct objlist *obj;
   struct SubWin *parent;
   n_list_store *list;
@@ -176,28 +189,32 @@ struct obj_list_data
   struct obj_list_data *next;
 };
 
+struct SubWin;
+
+typedef void (* sub_window_state_func) (struct SubWin *d, int state);
+
 struct SubWin
 {
   enum SubWinType type;
   GtkWidget *Win;
   GdkWindowState window_state;
+  int visible, action_widget_id;
   union {
     struct obj_list_data *data;
     GtkWidget *text;
   } data;
+  sub_window_state_func state_func;
 };
 
 #define MENU_HISTORY_NUM 10
 
 struct NgraphApp
 {
-  int Interrupt;
   char *FileName;
   GtkWidget *Message, *Message_pos, *Message_extra;
   gint Message1;
-  GtkWidget *ghistory[MENU_HISTORY_NUM], *fhistory[MENU_HISTORY_NUM];
+  GtkRecentManager *recent_manager;
   GtkEntryCompletion *legend_text_list, *x_math_list, *y_math_list, *func_list, *fit_list;
-  GtkRadioAction *viewb;
 #if GTK_CHECK_VERSION(3, 0, 0)
   cairo_surface_t *markpix[MARK_TYPE_NUM];
 #else
@@ -219,11 +236,20 @@ extern struct NgraphApp NgraphApp;
 extern GtkWidget *TopLevel;
 extern GdkColor white, gray;
 extern GtkAccelGroup *AccelGroup;
+#if USE_GTK_BUILDER
+extern GtkApplication *GtkApp;
+#endif
+
+struct EventLoopInfo {
+  int type;
+  guint32 time;
+};
 
 int application(char *file);
 
 void set_current_window(GtkWidget *w);
 GtkWidget *get_current_window(void);
+GtkWidget *create_recent_menu(int type);
 void UpdateAll(void);
 void UpdateAll2(void);
 void ChangePage(void);
@@ -245,10 +271,16 @@ void set_axis_undo_button_sensitivity(int state);
 void set_modified_state(int state);
 void set_focus_insensitive(const struct Viewer *d);
 void set_focus_sensitivity(const struct Viewer *d);
-void window_action_set_active(enum SubWinType type, int state);
-void window_action_toggle(enum SubWinType type);
-char *get_ui_definition(void);
 void create_addin_menu(void);
 void create_recent_data_menu(void);
+void set_pointer_mode(int id);
+void set_toggle_action_widget_state(int id, int state);
+void set_subwindow_state(enum SubWinType id, enum subwin_state state);
+int get_subwindow_state(enum SubWinType id);
+void script_exec(GtkWidget *w, gpointer client_data);
+int toggle_view(int type, int state);
+void CmToggleSingleWindowMode(GtkCheckMenuItem *action, gpointer client_data);
+void CmReloadWindowConfig(void *w, gpointer user_data);
+void show_recent_dialog(int type);
 
 #endif
