@@ -478,7 +478,7 @@ PrefScriptDialogSetup(GtkWidget *wi, void *data, int makewidget)
 
   d = (struct PrefScriptDialog *) data;
   if (makewidget) {
-    gtk_dialog_add_button(GTK_DIALOG(wi), GTK_STOCK_SAVE, IDSAVE);
+    gtk_dialog_add_button(GTK_DIALOG(wi), _("_Save"), IDSAVE);
     PrefScriptDialogCreateWidgets(d, NULL, sizeof(list) / sizeof(*list), list);
     gtk_window_set_default_size(GTK_WINDOW(wi), 400, 300);
     gtk_widget_show_all(GTK_WIDGET(d->vbox));
@@ -683,7 +683,7 @@ PrefDriverDialogSetup(GtkWidget *wi, void *data, int makewidget)
 
   d = (struct PrefDriverDialog *) data;
   if (makewidget) {
-    gtk_dialog_add_button(GTK_DIALOG(wi), GTK_STOCK_SAVE, IDSAVE);
+    gtk_dialog_add_button(GTK_DIALOG(wi), _("_Save"), IDSAVE);
     PrefDriverDialogCreateWidgets(d, NULL, sizeof(list) / sizeof(*list), list);
     gtk_window_set_default_size(GTK_WINDOW(wi), 400, 300);
     gtk_widget_show_all(GTK_WIDGET(d->vbox));
@@ -954,23 +954,27 @@ FontSettingDialogSetup(GtkWidget *wi, void *data, int makewidget)
     vbox = gtk_vbox_new(FALSE, 4);
 #endif
 
-    w = gtk_button_new_from_stock(GTK_STOCK_ADD);
+    w= gtk_button_new_with_mnemonic(_("_Add"));
+    set_button_icon(w, "list-add");
     g_signal_connect(w, "clicked", G_CALLBACK(FontSettingDialogAddAlternative), d);
     gtk_box_pack_start(GTK_BOX(vbox), w, FALSE, FALSE, 4);
 
-    w = gtk_button_new_from_stock(GTK_STOCK_REMOVE);
+    w = gtk_button_new_with_mnemonic(_("_Remove"));
+    set_button_icon(w, "list-remove");
     g_signal_connect(w, "clicked", G_CALLBACK(FontSettingDialogRemoveAlternative), d);
     gtk_box_pack_start(GTK_BOX(vbox), w, FALSE, FALSE, 4);
     gtk_widget_set_sensitive(w, FALSE);
     d->del_b = w;
 
-    w = gtk_button_new_from_stock(GTK_STOCK_GO_DOWN);
+    w = gtk_button_new_with_mnemonic(_("_Down"));
+    set_button_icon(w, "go-down");
     g_signal_connect(w, "clicked", G_CALLBACK(FontSettingDialogDownAlternative), d);
     gtk_box_pack_end(GTK_BOX(vbox), w, FALSE, FALSE, 4);
     gtk_widget_set_sensitive(w, FALSE);
     d->down_b = w;
 
-    w = gtk_button_new_from_stock(GTK_STOCK_GO_UP);
+    w = gtk_button_new_with_mnemonic(_("_Up"));
+    set_button_icon(w, "go-up");
     g_signal_connect(w, "clicked", G_CALLBACK(FontSettingDialogUpAlternative), d);
     gtk_box_pack_end(GTK_BOX(vbox), w, FALSE, FALSE, 4);
     gtk_widget_set_sensitive(w, FALSE);
@@ -1185,7 +1189,7 @@ PrefFontDialogSetup(GtkWidget *wi, void *data, int makewidget)
 
   d = (struct PrefFontDialog *) data;
   if (makewidget) {
-    gtk_dialog_add_button(GTK_DIALOG(wi), GTK_STOCK_SAVE, IDSAVE);
+    gtk_dialog_add_button(GTK_DIALOG(wi), _("_Save"), IDSAVE);
 
 #if GTK_CHECK_VERSION(3, 0, 0)
     vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 4);
@@ -1227,8 +1231,10 @@ MiscDialogSetupItem(GtkWidget *w, struct MiscDialog *d)
   if (Menulocal.help_browser)
     gtk_entry_set_text(GTK_ENTRY(d->help_browser), Menulocal.help_browser);
 
+#if ! GTK_CHECK_VERSION(3, 0, 0)
   if (Menulocal.browser)
     gtk_entry_set_text(GTK_ENTRY(d->browser), Menulocal.browser);
+#endif
 
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(d->directory), Menulocal.changedirectory);
 
@@ -1289,9 +1295,7 @@ MiscDialogSetup(GtkWidget *wi, void *data, int makewidget)
 
   d = (struct MiscDialog *) data;
   if (makewidget) {
-    d->show_cancel = FALSE;
-    gtk_dialog_add_button(GTK_DIALOG(wi), GTK_STOCK_CANCEL, IDCANCEL);
-    gtk_dialog_add_button(GTK_DIALOG(wi), GTK_STOCK_SAVE, IDSAVE);
+    gtk_dialog_add_button(GTK_DIALOG(wi), _("_Save"), IDSAVE);
 
 #if GTK_CHECK_VERSION(3, 0, 0)
     hbox2 = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 4);
@@ -1318,9 +1322,11 @@ MiscDialogSetup(GtkWidget *wi, void *data, int makewidget)
     add_widget_to_table(table, w, _("_Help browser:"), TRUE, i++);
     d->help_browser = w;
 
+#if ! GTK_CHECK_VERSION(3, 0, 0)
     w = create_file_entry_with_cb(G_CALLBACK(set_file_in_entry), d);
     add_widget_to_table(table, w, _("_Web browser:"), TRUE, i++);
     d->browser = w;
+#endif
 
     gtk_container_add(GTK_CONTAINER(frame), table);
     gtk_box_pack_start(GTK_BOX(vbox2), frame, FALSE, FALSE, 4);
@@ -1528,7 +1534,9 @@ MiscDialogClose(GtkWidget *w, void *data)
 
   set_program_name(d->editor, &Menulocal.editor);
   set_program_name(d->help_browser, &Menulocal.help_browser);
+#if ! GTK_CHECK_VERSION(3, 0, 0)
   set_program_name(d->browser, &Menulocal.browser);
+#endif
 
   Menulocal.changedirectory =
     gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(d->directory));
@@ -1633,9 +1641,7 @@ ExViewerDialogSetup(GtkWidget *wi, void *data, int makewidget)
 
   d = (struct ExViewerDialog *) data;
   if (makewidget) {
-    d->show_cancel = FALSE;
-    gtk_dialog_add_button(GTK_DIALOG(wi), GTK_STOCK_CANCEL, IDCANCEL);
-    gtk_dialog_add_button(GTK_DIALOG(wi), GTK_STOCK_SAVE, IDSAVE);
+    gtk_dialog_add_button(GTK_DIALOG(wi), _("_Save"), IDSAVE);
 
 #if GTK_CHECK_VERSION(3, 4, 0)
     table = gtk_grid_new();
@@ -1763,9 +1769,7 @@ ViewerDialogSetup(GtkWidget *wi, void *data, int makewidget)
 
   d = (struct ViewerDialog *) data;
   if (makewidget) {
-    d->show_cancel = FALSE;
-    gtk_dialog_add_button(GTK_DIALOG(wi), GTK_STOCK_CANCEL, IDCANCEL);
-    gtk_dialog_add_button(GTK_DIALOG(wi), GTK_STOCK_SAVE, IDSAVE);
+    gtk_dialog_add_button(GTK_DIALOG(wi), _("_Save"), IDSAVE);
 
 #if GTK_CHECK_VERSION(3, 4, 0)
     table = gtk_grid_new();
@@ -1902,7 +1906,7 @@ ViewerDialog(struct ViewerDialog *data, struct objlist *obj, int id)
 }
 
 void
-CmOptionSaveNgp(GtkAction *w, gpointer client_data)
+CmOptionSaveNgp(void *w, gpointer client_data)
 {
   char *ngpfile;
   char mes[MESSAGE_BUF_SIZE];
@@ -1918,7 +1922,7 @@ CmOptionSaveNgp(GtkAction *w, gpointer client_data)
 
   path = 1;
 
-  obj = chkobject("file");
+  obj = chkobject("data");
   if (obj) {
     for (i = 0; i <= chkobjlastinst(obj); i++) {
       putobj(obj, "save_path", i, &path);
@@ -1949,7 +1953,7 @@ CmOptionSaveNgp(GtkAction *w, gpointer client_data)
 }
 
 void
-CmOptionViewer(GtkAction *w, gpointer client_data)
+CmOptionViewer(void *w, gpointer client_data)
 {
   int r;
 
@@ -1964,7 +1968,7 @@ CmOptionViewer(GtkAction *w, gpointer client_data)
 }
 
 void
-CmOptionExtViewer(GtkAction *w, gpointer client_data)
+CmOptionExtViewer(void *w, gpointer client_data)
 {
   if (Menulock || Globallock)
     return;
@@ -1973,7 +1977,7 @@ CmOptionExtViewer(GtkAction *w, gpointer client_data)
 }
 
 void
-CmOptionPrefFont(GtkAction *w, gpointer client_data)
+CmOptionPrefFont(void *w, gpointer client_data)
 {
   if (Menulock || Globallock)
     return;
@@ -1993,7 +1997,7 @@ CmOptionPrefDriver(void)
 #endif
 
 void
-CmOptionScript(GtkAction *w, gpointer client_datavoid)
+CmOptionScript(void *w, gpointer client_datavoid)
 {
   if (Menulock || Globallock)
     return;
@@ -2002,7 +2006,7 @@ CmOptionScript(GtkAction *w, gpointer client_datavoid)
 }
 
 void
-CmOptionMisc(GtkAction *w, gpointer client_data)
+CmOptionMisc(void *w, gpointer client_data)
 {
   if (Menulock || Globallock)
     return;
@@ -2011,7 +2015,7 @@ CmOptionMisc(GtkAction *w, gpointer client_data)
 }
 
 void
-CmOptionSaveDefault(GtkAction *w, gpointer client_data)
+CmOptionSaveDefault(void *w, gpointer client_data)
 {
   if (Menulock || Globallock)
     return;
