@@ -398,7 +398,7 @@ getextention(char *name)
 }
 
 char *
-getfilename(char *dir,char *sep,char *file)
+getfilename(const char *dir, const char *sep, const char *file)
 {
   char *s;
   unsigned int dir_len;
@@ -421,7 +421,7 @@ getfilename(char *dir,char *sep,char *file)
 }
 
 int 
-findfilename(char *dir,char *sep,char *file)
+findfilename(const char *dir, const char *sep, const char *file)
 {
   char *s;
   int find;
