@@ -17,6 +17,7 @@
 #endif
 
 #include "ntime.h"
+#include "object.h"
 
 #include "math_equation.h"
 #include "math_function.h"
@@ -1250,6 +1251,16 @@ math_func_unix2mjd(MathFunctionCallExpression *exp, MathEquation *eq, MathValue
   return 0;
 }
 
+int
+math_func_mjd2unix(MathFunctionCallExpression *exp, MathEquation *eq, MathValue *rval)
+{
+  MATH_CHECK_ARG(rval, exp->buf[0]);
+
+  rval->val = (exp->buf[0].val.val - 40587) * 86400;
+
+  return 0;
+}
+
 int
 math_func_mjd2year(MathFunctionCallExpression *exp, MathEquation *eq, MathValue *rval)
 {
@@ -2380,7 +2391,7 @@ math_func_m(MathFunctionCallExpression *exp, MathEquation *eq, MathValue *rval)
 int
 math_func_for(MathFunctionCallExpression *exp, MathEquation *eq, MathValue *rval)
 {
-  int n, r;
+  int n, r, i;
   double v, start, stop, step;
   MathFunctionArgument *argv;
 
@@ -2409,8 +2420,13 @@ math_func_for(MathFunctionCallExpression *exp, MathEquation *eq, MathValue *rval
     Memory[n].type = MATH_VALUE_NORMAL;
   }
 
+  i = 0;
   rval->val = 0;
   for (v = start; (step < 0) ?  (v >= stop) : (v <= stop); v += step) {
+    if ((i & 0xff) == 0 && ninterrupt()) {
+      rval->type = MATH_VALUE_INTERRUPT;
+      return 1;
+    }
     if (n >= 0) {
       Memory[n].val = v;
     }
@@ -2418,6 +2434,70 @@ math_func_for(MathFunctionCallExpression *exp, MathEquation *eq, MathValue *rval
     if(r) {
       return r;
     }
+    if (rval->type == MATH_VALUE_ERROR) {
+      return 1;
+    }
+    i++;
+  }
+
+  return 0;
+}
+
+int
+math_func_while(MathFunctionCallExpression *exp, MathEquation *eq, MathValue *rval)
+{
+  int n, r, i;
+  MathFunctionArgument *argv;
+  MathValue condition;
+
+  if (Memory == NULL && init_memory()) {
+    return 1;
+  }
+
+  argv = exp->buf;
+
+  MATH_CHECK_ARG(rval, argv[0]);
+
+  n = argv[0].val.val;
+
+  if (n >= MATH_FUNCTION_MEMORY_NUM) {
+    rval->type = MATH_VALUE_ERROR;
+    return 1;
+  }
+
+  if (n >= 0) {
+    Memory[n].type = MATH_VALUE_NORMAL;
+  }
+
+  rval->val = 0;
+  rval->type = MATH_VALUE_UNDEF;
+  condition.val = 0;
+  condition.type = MATH_VALUE_NORMAL;
+  for (i = 0; ; i++) {
+    if ((i & 0xff) == 0 && ninterrupt()) {
+      rval->type = MATH_VALUE_INTERRUPT;
+      return 1;
+    }
+
+    if (n >= 0) {
+      Memory[n].val = i;
+    }
+
+     r = math_expression_calculate(argv[1].exp, &condition);
+    if(r) {
+      return r;
+    }
+    if (condition.type == MATH_VALUE_ERROR) {
+      return 1;
+    }
+    if (condition.val == 0.0) {
+      break;
+    }
+
+    r = math_expression_calculate(argv[2].exp, rval);
+    if(r) {
+      return r;
+    }
   }
 
   return 0;
@@ -2687,3 +2767,25 @@ math_func_dif(MathFunctionCallExpression *exp, MathEquation *eq, MathValue *rval
 
   return 0;
 }
+
+int
+math_func_fmod(MathFunctionCallExpression *exp, MathEquation *eq, MathValue *rval)
+{
+  double x, y;
+
+  MATH_CHECK_ARG(rval, exp->buf[0]);
+  MATH_CHECK_ARG(rval, exp->buf[1]);
+
+  x = exp->buf[0].val.val;
+  y = exp->buf[1].val.val;
+
+  if (y == 0.0) {
+    rval->type = MATH_VALUE_NAN;
+    rval->val = 0.0;
+    return 0;
+  }
+
+  rval->val = fmod(x, y);
+
+  return 0;
+}
