@@ -3,6 +3,8 @@
  * 
  */
 
+#include "config.h"
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -584,6 +586,7 @@ create_variable_assign_expression(MathEquation *eq, enum MATH_OPERATOR_TYPE op,
 {
   MathExpression *exp, *bin;
 
+  bin = NULL;
   switch (op) {
   case MATH_OPERATOR_TYPE_ASSIGN:
     break;
