@@ -24,6 +24,8 @@
 #include "nstring.h"
 #include "nconfig.h"
 
+#include "math/math_equation.h"
+
 #define NAME "axis"
 #define PARENT "draw"
 #define OVERSION  "1.00.00"
@@ -39,6 +41,7 @@
 #define ERRMINMAX 104
 #define ERRFORMAT 105
 #define ERRGROUPING 106
+#define ERRNUMMATH 107
 
 static char *axiserrorlist[]={
   "illegal axis type.",
@@ -48,6 +51,7 @@ static char *axiserrorlist[]={
   "illegal value of min/max/inc.",
   "illegal format.",
   "illegal grouping type.",
+  "error in math:",
 };
 
 #define ERRNUM (sizeof(axiserrorlist) / sizeof(*axiserrorlist))
@@ -228,7 +232,7 @@ axisinit(struct objlist *obj,N_VALUE *inst,N_VALUE *rval,int argc,char **argv)
   int len1,wid1,len2,wid2,len3,wid3;
   int pt,sx,sy,logpow,scriptsize;
   int autonorm,num,gnum,margin;
-  char *font,*format,*group,*name, buf[256];
+  char *font,*format,*group,*name;
 
   if (_exeparent(obj,(char *)argv[1],inst,rval,argc,argv)) return 1;
   width=40;
@@ -286,13 +290,11 @@ axisinit(struct objlist *obj,N_VALUE *inst,N_VALUE *rval,int argc,char **argv)
   if (_putobj(obj,"num_font",inst,font)) goto errexit;
 
   gnum = axisuniqgroup(obj,'a');
-  snprintf(buf, sizeof(buf), "a_%d",gnum);
-  group = g_strdup(buf);
+  group = g_strdup_printf("a_%d", gnum);
   if (group == NULL) goto errexit;
   if (_putobj(obj,"group",inst,group)) goto errexit;
 
-  snprintf(buf, sizeof(buf), "a_%d",gnum);
-  name = g_strdup(buf);
+  name = g_strdup_printf("a_%d",gnum);
   if (name == NULL) goto errexit;
   if (_putobj(obj,"name",inst,name)) goto errexit;
 
@@ -316,12 +318,11 @@ axisdone(struct objlist *obj,N_VALUE *inst,N_VALUE *rval,int argc,char **argv)
   get_axis_group_type(obj, inst, inst_array, TRUE);
   for (i = 0; i < INST_ARRAY_NUM; i++) {
     if (inst_array[i] && inst_array[i] != inst) {
-      char buf[64], *group, *group2;
+      char *group, *group2;
       int gnum;
 
       gnum = axisuniqgroup(obj,'a');
-      snprintf(buf, sizeof(buf), "a_%d",gnum);
-      group = g_strdup(buf);
+      group = g_strdup_printf("a_%d", gnum);
       if (group == NULL)
 	break;
 
@@ -1587,6 +1588,7 @@ struct axis_config {
   int length, width;
   int direction;		/* direction in degree multiplied 100 */
   double dir;			/* direction in radian */
+  MathEquation *code;
 };
 
 
@@ -1997,6 +1999,26 @@ get_axis_gauge_num_str(const char *format, double a)
   return g_string_free(num, FALSE);
 }
 
+static double
+calc_numbering_value(const struct axis_config *aconf, double po)
+{
+  MathValue val;
+
+  if (aconf->code) {
+    val.val = po;
+    val.type = MATH_VALUE_NORMAL;
+    math_equation_set_var(aconf->code, 0, &val);
+    math_equation_calculate(aconf->code, &val);
+    if (val.type == MATH_VALUE_NORMAL) {
+      po = val.val;
+    } else {
+      po = 0;
+    }
+  }
+
+  return po;
+}
+
 static double
 numformat(char **text, int *nlen, const char *format,
 	  const struct axis_config *aconf,
@@ -2013,10 +2035,12 @@ numformat(char **text, int *nlen, const char *format,
 
   if ((! logpow && (alocal->atype == AXISLOGBIG || alocal->atype == AXISLOGNORM)) ||
       (alocal->atype == AXISLOGSMALL)) {
+    po = calc_numbering_value(aconf, po);
     a = pow(10.0, po);
   } else if (alocal->atype == AXISINVERSE) {
-    a = 1.0 / po;
+    a = calc_numbering_value(aconf, 1.0 / po);
   } else {
+    po = calc_numbering_value(aconf, po);
     a = po / norm;
   }
 
@@ -2449,7 +2473,7 @@ numbering(struct objlist *obj, N_VALUE *inst, int GC, struct axis_config *aconf,
   step = get_step(&alocal, step, &begin);
 
   norm = 1;
-  if (alocal.atype == AXISNORMAL) {
+  if (alocal.atype == AXISNORMAL && aconf->code == NULL) {
     double abs_pos;
     abs_pos = fabs(alocal.dposm);
     if (abs_pos >= pow(10.0, (double) autonorm) ||
@@ -2660,14 +2684,77 @@ draw_gauge(struct objlist *obj,N_VALUE *inst, int GC, struct axis_config *aconf)
 }
 
 static int
-get_axis_parameter(struct objlist *obj, N_VALUE *inst,  struct axis_config *aconf)
+get_axis_parameter(struct objlist *obj, N_VALUE *inst, struct axis_config *aconf)
 {
   _getobj(obj, "min",  inst, &aconf->min);
   _getobj(obj, "max",  inst, &aconf->max);
   _getobj(obj, "inc",  inst, &aconf->inc);
   _getobj(obj, "div",  inst, &aconf->div);
   _getobj(obj, "type", inst, &aconf->type);
+  return 0;
+}
 
+static MathEquation *
+get_axis_math(struct objlist *obj, const char *math)
+{
+  MathEquation *code;
+  int rcode;
+
+  code = math_equation_basic_new();
+  if (code == NULL) {
+    return NULL;
+  }
+
+  if (math_equation_add_var(code, "X") != 0) {
+    math_equation_free(code);
+    return NULL;
+  }
+
+  rcode = math_equation_parse(code, math);
+  if (rcode) {
+    char *err_msg;;
+
+    err_msg = math_err_get_error_message(code, math, rcode);
+    error2(obj, ERRNUMMATH, err_msg);
+    g_free(err_msg);
+    math_equation_free(code);
+    return NULL;
+  }
+
+  return code;
+}
+
+static int
+alloc_axis_math(struct objlist *obj, N_VALUE *inst, struct axis_config *aconf)
+{
+  char *math;
+  MathEquation *code;
+
+  aconf->code = NULL;
+
+  _getobj(obj, "num_math", inst, &math);
+  if (math == NULL) {
+    return 0;
+  }
+
+  if (math == NULL || math[0] == '\0') {
+    code = NULL;
+  } else {
+    code = get_axis_math(obj, math);
+  }
+
+  aconf->code = code;
+
+  return 0;
+}
+
+static int
+free_axis_math(struct axis_config *aconf)
+{
+  if (aconf->code) {
+    math_equation_free(aconf->code);
+  }
+  aconf->code = NULL;
   return 0;
 }
 
@@ -2679,6 +2766,7 @@ get_reference_parameter(struct objlist *obj, N_VALUE *inst,  struct axis_config
   struct objlist *aobj;
   int anum, id;
   struct narray iarray;
+  int type;
 
   _getobj(obj,"reference",inst, &axis);
   if (axis == NULL)
@@ -2688,6 +2776,8 @@ get_reference_parameter(struct objlist *obj, N_VALUE *inst,  struct axis_config
   if (getobjilist(axis,&aobj,&iarray,FALSE,NULL))
     return 1;
 
+  type = aconf->type;
+
   anum=arraynum(&iarray);
   if (anum>0) {
     id=arraylast_int(&iarray);
@@ -2697,6 +2787,13 @@ get_reference_parameter(struct objlist *obj, N_VALUE *inst,  struct axis_config
     }
   }
 
+  if ((aconf->type == AXIS_TYPE_LINEAR ||
+       aconf->type == AXIS_TYPE_MJD) &&
+      (type == AXIS_TYPE_LINEAR ||
+       type == AXIS_TYPE_MJD)) {
+    aconf->type = type;
+  }	/* AXIS_TYPE_LINEAR and AXIS_TYPE_MJD are compatible each other */
+
   return 0;
 }
 
@@ -2839,6 +2936,8 @@ axisdraw(struct objlist *obj,N_VALUE *inst,N_VALUE *rval,int argc,char **argv)
   int hidden, hidden2;
   struct axis_config aconf;
 
+  aconf.code = NULL;
+
   _getobj(obj,"hidden",inst,&hidden);
   hidden2=FALSE;
   _putobj(obj,"hidden",inst,&hidden2);
@@ -2872,6 +2971,7 @@ axisdraw(struct objlist *obj,N_VALUE *inst,N_VALUE *rval,int argc,char **argv)
   aconf.dir=aconf.direction/18000.0*MPI;
   aconf.x1=aconf.x0+nround(aconf.length*cos(aconf.dir));
   aconf.y1=aconf.y0-nround(aconf.length*sin(aconf.dir));
+  alloc_axis_math(obj, inst, &aconf);
 
   GRAregion(GC,&w,&h,&zoom);
   GRAview(GC,0,0,w*10000.0/zoom,h*10000.0/zoom,clip);
@@ -2897,12 +2997,15 @@ axisdraw(struct objlist *obj,N_VALUE *inst,N_VALUE *rval,int argc,char **argv)
     goto exit;
   }
 
-  get_axis_parameter(obj, inst, &aconf);
+  if (aconf.code == NULL) {
+    get_axis_parameter(obj, inst, &aconf);
+  }
   if (aconf.min != aconf.max && aconf.inc != 0) {
     numbering(obj, inst, GC, &aconf, NULL);
   }
 
 exit:
+  free_axis_math(&aconf);
   GRAaddlist(GC,obj,inst,(char *)argv[0],(char *)argv[1]);
   return 0;
 }
@@ -2938,16 +3041,19 @@ axis_get_numbering(struct objlist *obj, N_VALUE *inst, N_VALUE *rval, int argc,
   aconf.dir = aconf.direction / 18000.0 * MPI;
   aconf.x1 = aconf.x0+nround(aconf.length * cos(aconf.dir));
   aconf.y1 = aconf.y0-nround(aconf.length * sin(aconf.dir));
+  alloc_axis_math(obj, inst, &aconf);
 
   get_axis_parameter(obj, inst, &aconf);
   if (aconf.min != aconf.max && aconf.inc != 0) {
     array = arraynew(sizeof(char *));
     if (array == NULL) {
+      free_axis_math(&aconf);
       return 1;
     }
     numbering(obj, inst, GC, &aconf, array);
     rval->array = array;
   }
+  free_axis_math(&aconf);
 
   return 0;
 }
@@ -3311,11 +3417,10 @@ axistight(struct objlist *obj,N_VALUE *inst,N_VALUE *rval, int argc,char **argv)
   return 0;
 }
 
-#define BUF_SIZE 64
 static void
 set_group(struct objlist *obj, int gnum, int id, char axis, char type)
 {
-  char *group, *group2, buf[BUF_SIZE];
+  char *group, *group2;
   N_VALUE *inst2;
 
   inst2 = chkobjinst(obj, id);
@@ -3323,15 +3428,14 @@ set_group(struct objlist *obj, int gnum, int id, char axis, char type)
     return;
   }
 
-  snprintf(buf, sizeof(buf), "%c%c%d", type, axis, gnum);
-  group = g_strdup(buf);
+  group = g_strdup_printf("%c%c%d", type, axis, gnum);
   if (group) {
     _getobj(obj, "group", inst2, &group2);
     g_free(group2);
     _putobj(obj, "group", inst2, group);
   }
 
-  group = g_strdup(buf);
+  group = g_strdup_printf("%c%c%d", type, axis, gnum);
   if (group) {
     _getobj(obj, "name", inst2, &group2);
     g_free(group2);
@@ -3490,14 +3594,13 @@ static void
 axis_default_set(struct objlist *obj, int id, int oid, char *field, char *conf)
 {
   N_VALUE *inst2;
-  char *ref, *ref2, buf[BUF_SIZE];
+  char *ref, *ref2;
 
   inst2 = chkobjinst(obj, id);
   if (inst2 == NULL)
     return;
 
-  snprintf(buf, sizeof(buf), "axis:^%d", oid);
-  ref = g_strdup(buf);
+  ref = g_strdup_printf("axis:^%d", oid);
   if (ref == NULL)
     return;
 
@@ -3791,6 +3894,45 @@ anumdirput(struct objlist *obj,N_VALUE *inst,N_VALUE *rval, int argc,char **argv
   return 0;
 }
 
+static int 
+num_put_math(struct objlist *obj,N_VALUE *inst,N_VALUE *rval,int argc,char **argv)
+{
+  MathEquation *code;
+  char *math;
+
+  math = argv[2];
+  if (math == NULL) {
+    return 0;
+  }
+
+  g_strstrip(math);
+  if (math[0] == '\0') {
+    g_free(argv[2]);
+    argv[2] = NULL;
+    return 0;
+  }
+
+  code = get_axis_math(obj, math);
+  if (code) {
+    math_equation_free(code);
+    return 0;
+  }
+
+  return 1;
+}
+
+static int
+put_gauge_hsb(struct objlist *obj, N_VALUE *inst, N_VALUE *rval, int argc, char **argv)
+{
+  return put_hsb_color(obj, inst, argc, argv, "gauge_%c");
+}
+
+static int
+put_num_hsb(struct objlist *obj, N_VALUE *inst, N_VALUE *rval, int argc, char **argv)
+{
+  return put_hsb_color(obj, inst, argc, argv, "num_%c");
+}
+
 static struct objtable axis[] = {
   {"init",NVFUNC,NEXEC,axisinit,NULL,0},
   {"done",NVFUNC,NEXEC,axisdone,NULL,0},
@@ -3856,6 +3998,7 @@ static struct objtable axis[] = {
   {"num_B",NINT,NREAD|NWRITE,NULL,NULL,0},
   {"num_A",NINT,NREAD|NWRITE,NULL,NULL,0},
   {"num_date_format",NSTR,NREAD|NWRITE,NULL,NULL,0},
+  {"num_math",NSTR,NREAD|NWRITE,num_put_math,NULL,0},
   {"scale_push",NVFUNC,NREAD|NEXEC,axisscalepush,"",0},
   {"scale_pop",NVFUNC,NREAD|NEXEC,axisscalepop,"",0},
   {"scale_history",NDARRAY,NREAD,NULL,NULL,0},
@@ -3881,6 +4024,10 @@ static struct objtable axis[] = {
   {"get_numbering",NSAFUNC,NREAD|NEXEC,axis_get_numbering,"",0},
   {"save",NSFUNC,NREAD|NEXEC,axissave,"sa",0},
 
+  {"hsb", NVFUNC, NREAD|NEXEC, put_hsb,"ddd",0},
+  {"gauge_hsb", NVFUNC, NREAD|NEXEC, put_gauge_hsb,"ddd",0},
+  {"num_hsb", NVFUNC, NREAD|NEXEC, put_num_hsb,"ddd",0},
+
   /* following fields exist for backward compatibility */
   {"num_jfont",NSTR,NWRITE,NULL,NULL,0},
 };
