@@ -36,7 +36,7 @@
 #include "mathfn.h"
 #include "oroot.h"
 #include "ofit.h"
-#include "ofile.h"
+#include "odata.h"
 
 #include "math/math_equation.h"
 
@@ -611,7 +611,7 @@ fituser(struct objlist *obj,struct fitlocal *fitlocal, const char *func,
 {
   int ecode;
   int *needdata;
-  int tbl[10],dim,n,count,rcode,err,err2,err3;
+  int tbl[10],dim,n,count,err,err2,err3;
   double yy,y,y1,y2,y3,sy,spx,spy,dxx,dxxc,xx,derror,correlation;
   double b[10],x2[10],parerr[10];
   MathValue par[10], par2[10], var;
@@ -703,18 +703,18 @@ fituser(struct objlist *obj,struct fitlocal *fitlocal, const char *func,
       var.type = MATH_VALUE_NORMAL;
       math_equation_set_parameter_data(fitlocal->codef, 0, par);
       math_equation_set_var(fitlocal->codef, 0, &var);
-      rcode = math_equation_calculate(fitlocal->codef, &var);
+      math_equation_calculate(fitlocal->codef, &var);
       y1 = var.val;
-      if (rcode!=MATH_VALUE_NORMAL) err=TRUE;
+      if (var.type!=MATH_VALUE_NORMAL) err=TRUE;
       if (deriv) {
         for (j=0;j<dim;j++) {
 	  var.val = spx;
 	  var.type = MATH_VALUE_NORMAL;
 	  math_equation_set_parameter_data(fitlocal->codedf[tbl[j]], 0, par);
 	  math_equation_set_var(fitlocal->codedf[tbl[j]], 0, &var);
-	  rcode = math_equation_calculate(fitlocal->codedf[tbl[j]], &var);
+	  math_equation_calculate(fitlocal->codedf[tbl[j]], &var);
 	  x2[j] = var.val;
-	  if (rcode!=MATH_VALUE_NORMAL) err=TRUE;
+	  if (var.type!=MATH_VALUE_NORMAL) err=TRUE;
         }
       } else {
         for (j=0;j<dim;j++) {
@@ -726,9 +726,9 @@ fituser(struct objlist *obj,struct fitlocal *fitlocal, const char *func,
 	  var.type = MATH_VALUE_NORMAL;
 	  math_equation_set_parameter_data(fitlocal->codef, 0, par2);
 	  math_equation_set_var(fitlocal->codef, 0, &var);
-	  rcode = math_equation_calculate(fitlocal->codef, &var);
+	  math_equation_calculate(fitlocal->codef, &var);
 	  x2[j] = var.val;
-	  if (rcode!=MATH_VALUE_NORMAL) err=TRUE;
+	  if (var.type!=MATH_VALUE_NORMAL) err=TRUE;
           x2[j]=(x2[j]-y1)/dxx;
         }
       }
