@@ -44,7 +44,7 @@
 
 #define ERRSPL  100
 static char *patherrorlist[]={
-  "error: spline interpolation."
+  "error: spline interpolation.",
 };
 
 #define ERRNUM (sizeof(patherrorlist) / sizeof(*patherrorlist))
@@ -350,7 +350,7 @@ curve_expand_points(struct objlist *obj, N_VALUE *inst, int intp, struct narray
       if (! curve_expand(c, c[0], c[4], bsplinedif, bsplineint, expand_points)) {
 	return 0;
       }
-    }      
+    }
 
     for (j = 0; j < 2; j++) {
       bspline(j + 3, bs1 + j + 2, c);
@@ -1080,6 +1080,8 @@ static struct objtable arrow[] = {
   {"zooming", NVFUNC, NREAD|NEXEC, curve_zoom, "iiii", 0},
   {"match", NBFUNC, NREAD|NEXEC, curvematch, "iiiii", 0},
 
+  {"fill_hsb", NVFUNC, NREAD|NEXEC, put_fill_hsb,"ddd",0},
+  {"stroke_hsb", NVFUNC, NREAD|NEXEC, put_stroke_hsb,"ddd",0},
 
   /* following fields exist for backward compatibility */
   {"R", NINT, NWRITE, put_color_for_backward_compatibility, NULL, 0},
