@@ -90,6 +90,14 @@ cmddone(struct objlist *obj,N_VALUE *inst,N_VALUE *rval,int argc,char **argv)
   return 0;
 }
 
+#ifndef WINDOWS
+static void
+int_handler(int sig)
+{
+  set_interrupt();
+}
+#endif
+
 static int 
 cmdshell(struct objlist *obj,N_VALUE *inst,N_VALUE *rval,int argc,char **argv)
 {
@@ -103,6 +111,10 @@ cmdshell(struct objlist *obj,N_VALUE *inst,N_VALUE *rval,int argc,char **argv)
   int fd;
   int rcode;
   char *s;
+#ifndef WINDOWS
+  struct sigaction oldact;
+  int (*save_interrupt)(void);
+#endif
 
   _getobj(obj,"_local",inst,&shlocal);
 
@@ -114,6 +126,11 @@ cmdshell(struct objlist *obj,N_VALUE *inst,N_VALUE *rval,int argc,char **argv)
   nshell=shlocal->nshell;
 
   shellsavestdio(nshell);
+#ifndef WINDOWS
+  save_interrupt = ninterrupt;
+  set_signal(SIGINT, 0, int_handler, &oldact);
+  ninterrupt = check_interrupt;
+#endif
 
   err=1;
   filename=NULL;
@@ -180,6 +197,10 @@ cmdshell(struct objlist *obj,N_VALUE *inst,N_VALUE *rval,int argc,char **argv)
   err=0;
 
 errexit:
+#ifndef WINDOWS
+  ninterrupt = save_interrupt;
+  sigaction(SIGINT, &oldact, NULL);
+#endif
   shellrestorestdio(nshell);
 
   if (nshell->deleted) {
